@@ -43,7 +43,9 @@ using namespace std;
 #define BONDTYPE_SINGLE 1
 #define BONDTYPE_DOUBLE 2
 #define BONDTYPE_TRIPLE 3
-#define BONDTYPE_QUADRP 4	// never needed!!!
+//////////////////////////////////////////////////////
+//#define BONDTYPE_QUADRP 4	// never needed!!!
+//////////////////////////////////////////////////////
 
 /// A bondtype class.
 
@@ -53,10 +55,10 @@ class bondtype
 	
 	i32s type;
 	
-	static const char * string[5];
+	static const char * string[4];
 	
-	static const char symbol1[5];
-	static const char symbol2[5];
+	static const char symbol1[4];
+	static const char symbol2[4];
 	
 	public:
 	
@@ -78,7 +80,7 @@ class bondtype
 	void operator++(void);
 	void operator--(void);
 	
-	friend ostream & operator<<(ostream &, bondtype &);
+//	friend ostream & operator<<(ostream &, bondtype &);	this is not needed...
 };
 
 /*################################################################################################*/
