@@ -25,7 +25,10 @@
 #include "eng1_mm_default.h"
 #include "eng1_mm_prmfit.h"
 
-#include <cstring>	// required by gcc-4.3
+#include "local_i18n.h"
+#include "notice.h"
+
+#include <cstring>
 #include <algorithm>
 #include <sstream>
 using namespace std;
@@ -46,12 +49,12 @@ const i32u setup1_mm::eng_id_tab[] =
 
 const char * setup1_mm::eng_name_tab[] =
 {
-	"tripos5.2 implementation ported from ghemical-1.00",
+	_("eng1_mm_tripos52 : Tripos5.2 implementation (from ghemical-1.00)"),
 	
-	"the default engine (under construction) ; default_bp",
-	"the periodic engine (minimum image model) ; default_mim",
+	_("eng1_mm_default_bp : The default engine (under construction)"),
+	_("eng1_mm_default_mim : The periodic engine (minimum image model)"),
 	
-	"experimental ; eng1_prmfit",
+	_("eng1_mm_prmfit : Experimental"),
 	
 	NULL
 };
@@ -126,8 +129,7 @@ engine * setup1_mm::CreateEngineByIndex(i32u eng_index)
 {
 	if (eng_index >= GetEngineCount())
 	{
-		cout << "setup1_mm::CreateEngineByIndex() failed!" << endl;
-		return NULL;
+		assertion_failed(__FILE__, __LINE__, "bad eng_index.");
 	}
 	
 	GetModel()->UpdateIndex();
@@ -150,12 +152,12 @@ strcpy(forcefield_path, fps.str().c_str());
 	{
 		case ENG1_MM_DEFAULT:
 		GetModel()->use_periodic_boundary_conditions = false;
-if (GetModel()->use_boundary_potential) GetModel()->Message("use_boundary_potential = TRUE");
+if (GetModel()->use_boundary_potential) GetModel()->PrintToLog(_("Using boundary potential for solvent."));
 		return new eng1_mm_default_bp(this, 1);
 		
 		case ENG1_MM_TRIPOS52:
 		GetModel()->use_periodic_boundary_conditions = false;
-if (GetModel()->use_boundary_potential) GetModel()->Message("use_boundary_potential = TRUE");
+if (GetModel()->use_boundary_potential) GetModel()->PrintToLog(_("Using boundary potential for solvent."));
 		return new eng1_mm_tripos52_bp(this, 1);
 		
 		case ENG1_MM_PERIODIC:
@@ -171,7 +173,7 @@ if (GetModel()->use_boundary_potential) GetModel()->Message("use_boundary_potent
 		delete tab; return eng;
 		
 		default:
-		cout << "fatal error at setup1_mm::CreateEngineByIndex()" << endl;
+		assertion_failed(__FILE__, __LINE__, "bad eng_index.");
 		return NULL;
 	}
 }
@@ -214,11 +216,7 @@ eng1_mm::eng1_mm(setup * p1, i32u p2) : engine(p1, p2)
 			else index++;
 		}
 		
-		if (index >= GetSetup()->GetAtomCount())
-		{
-			cout << "BUG: eng1_mm ctor failed to create the l2g lookup table." << endl;
-			exit(EXIT_FAILURE);
-		}
+		if (index >= GetSetup()->GetAtomCount()) assertion_failed(__FILE__, __LINE__, "index >= GetSetup()->GetAtomCount()");
 		
 		l2g_mm[n1] = index;
 	}
