@@ -26,6 +26,9 @@
 #include "eng1_mm.h"
 #include "tab_mm_default.h"
 
+#include "local_i18n.h"
+#include "notice.h"
+
 #include <algorithm>
 #include <sstream>
 using namespace std;
@@ -63,14 +66,11 @@ eng1_mm_default_bt::eng1_mm_default_bt(setup * p1, i32u p2) :
 
 	// create bt1-terms...
 	
-	if (ostr != NULL) (* ostr) << "creating bt1-terms: ";
+	if (ostr != NULL) (* ostr) << _("creating bt1-terms: ");
 	i32s bt1_err = 0;
 	
-if (!GetSetup()->GetModel()->IsIndexClean())	// obsolete???
-	{
-		cout << "BUG: is_index_clean == false at eng1_mm_default_bt." << endl;
-		exit(EXIT_FAILURE);
-	}
+	// 2008-12-17 ; an old comment suggested this test is obsolete? ; PROBABLY NOT!!! TH
+	if (!GetSetup()->GetModel()->IsIndexClean()) assertion_failed(__FILE__, __LINE__, "is_index_clean");
 	
 	for (i32s n1 = 0;n1 < GetSetup()->GetMMBondCount();n1++)
 	{
@@ -80,11 +80,7 @@ if (!GetSetup()->GetModel()->IsIndexClean())	// obsolete???
 			if (atmtab[local_ind1] == bndtab[n1]->atmr[0]) break;
 			else local_ind1++;
 		}
-		if (local_ind1 >= GetSetup()->GetMMAtomCount())
-		{
-			cout << "BUG: local_ind1 search failed!" << endl;
-			exit(EXIT_FAILURE);
-		}
+		if (local_ind1 >= GetSetup()->GetMMAtomCount()) assertion_failed(__FILE__, __LINE__, "local_ind1");
 		
 		i32s local_ind2 = 0;
 		while (local_ind2 < GetSetup()->GetMMAtomCount())
@@ -92,11 +88,7 @@ if (!GetSetup()->GetModel()->IsIndexClean())	// obsolete???
 			if (atmtab[local_ind2] == bndtab[n1]->atmr[1]) break;
 			else local_ind2++;
 		}
-		if (local_ind2 >= GetSetup()->GetMMAtomCount())
-		{
-			cout << "BUG: local_ind2 search failed!" << endl;
-			exit(EXIT_FAILURE);
-		}
+		if (local_ind2 >= GetSetup()->GetMMAtomCount()) assertion_failed(__FILE__, __LINE__, "local_ind2");
 		
 		mm_default_bt1 newbt1;
 		newbt1.atmi[0] = local_ind1;		// this is a local index...
@@ -134,7 +126,7 @@ if (!GetSetup()->GetModel()->IsIndexClean())	// obsolete???
 		bt1_vector.push_back(newbt1);
 	}
 	
-	if (ostr != NULL) (* ostr) << bt1_vector.size() << " terms, " << bt1_err << " errors." << endl;
+	if (ostr != NULL) (* ostr) << bt1_vector.size() << _(" terms, ") << bt1_err << _(" errors.") << endl;
 	
 	bt1data = new mm_bt1_data[bt1_vector.size()];
 	
@@ -143,7 +135,7 @@ if (!GetSetup()->GetModel()->IsIndexClean())	// obsolete???
 	
 	// create bt2-terms...
 	
-	if (ostr != NULL) (* ostr) << "creating bt2-terms: ";
+	if (ostr != NULL) (* ostr) << _("creating bt2-terms: ");
 	i32s bt2_err = 0;
 	
 	for (i32s n1 = 0;n1 < GetSetup()->GetMMAtomCount();n1++)
@@ -211,7 +203,7 @@ if (!GetSetup()->GetModel()->IsIndexClean())	// obsolete???
 		}
 	}
 	
-	if (ostr != NULL) (* ostr) << bt2_vector.size() << " terms, " << bt2_err << " errors." << endl;
+	if (ostr != NULL) (* ostr) << bt2_vector.size() << _(" terms, ") << bt2_err << _(" errors.") << endl;
 	
 	bt2data = new mm_bt2_data[bt2_vector.size()];
 	
@@ -220,7 +212,7 @@ if (!GetSetup()->GetModel()->IsIndexClean())	// obsolete???
 	
 	// create bt3-terms...
 	
-	if (ostr != NULL) (* ostr) << "creating bt3-terms: ";
+	if (ostr != NULL) (* ostr) << _("creating bt3-terms: ");
 	i32s bt3_err = 0;
 	
 	for (i32s n1 = 0;n1 < GetSetup()->GetMMAtomCount();n1++)
@@ -386,14 +378,14 @@ if (!GetSetup()->GetModel()->IsIndexClean())	// obsolete???
 		}
 	}
 	
-	if (ostr != NULL) (* ostr) << bt3_vector.size() << " terms, " << bt3_err << " errors." << endl;
+	if (ostr != NULL) (* ostr) << bt3_vector.size() << _(" terms, ")<< bt3_err << _(" errors.") << endl;
 	
 /*##############################################*/
 /*##############################################*/
 
 	// create bt4-terms...
 	
-	if (ostr != NULL) (* ostr) << "creating bt4-terms: ";
+	if (ostr != NULL) (* ostr) << _("creating bt4-terms: ");
 	i32s bt4_err = 0;
 	
 	for (i32s n1 = 0;n1 < GetSetup()->GetMMAtomCount();n1++)
@@ -444,11 +436,7 @@ if (!GetSetup()->GetModel()->IsIndexClean())	// obsolete???
 				newbt4.index2++;
 			}
 			
-			if (newbt4.index2 == (i32s) bt2_vector.size())
-			{
-				cout << "BUG: bt2 missing for bt4!!!" << endl;
-				exit(EXIT_FAILURE);
-			}
+			if (newbt4.index2 == (i32s) bt2_vector.size()) assertion_failed(__FILE__, __LINE__, "index2 overflow");
 			
 			i32s iglob[4] =
 			{
@@ -467,15 +455,12 @@ if (!GetSetup()->GetModel()->IsIndexClean())	// obsolete???
 					else index++;
 				}
 				
-				if (index >= GetSetup()->GetMMAtomCount())
-				{
-					cout << "ERROR : iloc search failed!!!" << endl;
-					exit(EXIT_FAILURE);
-				}
+				if (index >= GetSetup()->GetMMAtomCount()) assertion_failed(__FILE__, __LINE__, "iloc search failed");
 				
 				newbt4.atmi[n9] = index;
 			}
-if (newbt4.atmi[1] != n1) { cout << "OOPS THIS IS NOT WORKING!!!" << endl; exit(EXIT_FAILURE); }
+			
+			if (newbt4.atmi[1] != n1) assertion_failed(__FILE__, __LINE__, "atmi[1] != n1");
 			
 			bool success = false;
 			if (dynamic_cast<setup1_mm *>(GetSetup())->GetExceptions())
@@ -512,7 +497,7 @@ if (newbt4.atmi[1] != n1) { cout << "OOPS THIS IS NOT WORKING!!!" << endl; exit(
 		}
 	}
 	
-	if (ostr != NULL) (* ostr) << bt4_vector.size() << " terms, " << bt4_err << " errors." << endl;
+	if (ostr != NULL) (* ostr) << bt4_vector.size() << _(" terms, ") << bt4_err << _(" errors.") << endl;
 	
 /*##############################################*/
 /*##############################################*/
@@ -523,7 +508,7 @@ if (newbt4.atmi[1] != n1) { cout << "OOPS THIS IS NOT WORKING!!!" << endl; exit(
 	if (total_err && GetSetup()->GetModel()->verbosity >= 2)
 	{
 		ostringstream str;
-		str << "WARNING : there were " << total_err << " missing parameters in the bonded terms." << endl << ends;
+		str << _("WARNING : there were ") << total_err << _(" missing parameters in the bonded terms.") << endl << ends;
 		GetSetup()->GetModel()->PrintToLog(str.str().c_str());
 	}
 }
@@ -551,11 +536,7 @@ i32s eng1_mm_default_bt::FindTorsion(atom * a1, atom * a2, atom * a3, atom * a4)
 			else index++;
 		}
 		
-		if (index >= GetSetup()->GetMMAtomCount())
-		{
-			cout << "ERROR : iloc search failed!!!" << endl;
-			exit(EXIT_FAILURE);
-		}
+		if (index >= GetSetup()->GetMMAtomCount()) assertion_failed(__FILE__, __LINE__, "iloc search failed");
 		
 		iloc[n1] = index;
 	}
@@ -1142,12 +1123,12 @@ eng1_mm_default_nbt_bp::eng1_mm_default_nbt_bp(setup * p1, i32u p2) :
 	
 	if (ostr != NULL && use_bp)
 	{
-		(* ostr) << "use_bp ; ";
+		(* ostr) << _("use_bp ; ");
 		(* ostr) << bp_rad_solute << " " << bp_fc_solute << " ; ";
 		(* ostr) << bp_rad_solvent << " " << bp_fc_solvent << endl;
 	}
 	
-	if (ostr != NULL) (* ostr) << "creating nbt1-terms: ";
+	if (ostr != NULL) (* ostr) << _("creating nbt1-terms: ");
 	i32s nbt1_err = 0;
 	
 	for (i32s ind1 = 0;ind1 < GetSetup()->GetMMAtomCount() - 1;ind1++)
@@ -1240,7 +1221,7 @@ eng1_mm_default_nbt_bp::eng1_mm_default_nbt_bp(setup * p1, i32u p2) :
 	if (total_err && GetSetup()->GetModel()->verbosity >= 2)
 	{
 		ostringstream str;
-		str << "WARNING : there were " << total_err << " missing parameters in the nonbonded terms." << endl << ends;
+		str << _("WARNING : there were ") << total_err << _(" missing parameters in the nonbonded terms.") << endl << ends;
 		GetSetup()->GetModel()->PrintToLog(str.str().c_str());
 	}
 }
@@ -1473,20 +1454,12 @@ void eng1_mm_default_nbt_mim::ComputeNBT1(i32u p1)
 	if (t2a < -box_HALFdim[n2])
 	{
 		t2a += 2.0 * box_HALFdim[n2];
-		if (t2a < -box_HALFdim[n2])
-		{
-			cout << "PBC failed ; a-" << endl;
-			exit(EXIT_FAILURE);
-		}
+		if (t2a < -box_HALFdim[n2]) assertion_failed(__FILE__, __LINE__, "PBC failed ; a-");
 	}
 	else if (t2a > +box_HALFdim[n2])
 	{
 		t2a -= 2.0 * box_HALFdim[n2];
-		if (t2a > +box_HALFdim[n2])
-		{
-			cout << "PBC failed ; a+" << endl;
-			exit(EXIT_FAILURE);
-		}
+		if (t2a > +box_HALFdim[n2]) assertion_failed(__FILE__, __LINE__, "PBC failed ; a+");
 	}
 			
 			f64 t2b = crd[l2g_mm[atmi[1]] * 3 + n2];
@@ -1494,20 +1467,12 @@ void eng1_mm_default_nbt_mim::ComputeNBT1(i32u p1)
 	if (t2b < -box_HALFdim[n2])
 	{
 		t2b += 2.0 * box_HALFdim[n2];
-		if (t2b < -box_HALFdim[n2])
-		{
-			cout << "PBC failed ; b-" << endl;
-			exit(EXIT_FAILURE);
-		}
+		if (t2b < -box_HALFdim[n2]) assertion_failed(__FILE__, __LINE__, "PBC failed ; b-");
 	}
 	else if (t2b > +box_HALFdim[n2])
 	{
 		t2b -= 2.0 * box_HALFdim[n2];
-		if (t2b > +box_HALFdim[n2])
-		{
-			cout << "PBC failed ; b+" << endl;
-			exit(EXIT_FAILURE);
-		}
+		if (t2b > +box_HALFdim[n2]) assertion_failed(__FILE__, __LINE__, "PBC failed ; b+");
 	}
 			
 			t1a[n2] = t2a - t2b;
@@ -1647,7 +1612,7 @@ void eng1_mm_default_nbt_mim::UpdateTerms(void)
 	
 	nbt1_vector.resize(0);
 	
-	if (ostr != NULL) (* ostr) << "creating nbt1-terms: ";
+	if (ostr != NULL) (* ostr) << _("creating nbt1-terms: ");
 	i32s nbt1_err = 0;
 	
 	for (i32s ind1 = 0;ind1 < GetSetup()->GetMMAtomCount() - 1;ind1++)
@@ -1673,20 +1638,12 @@ void eng1_mm_default_nbt_mim::UpdateTerms(void)
 	if (t2a < -box_HALFdim[n1])
 	{
 		t2a += 2.0 * box_HALFdim[n1];
-		if (t2a < -box_HALFdim[n1])
-		{
-			cout << "PBC failed ; a-" << endl;
-			exit(EXIT_FAILURE);
-		}
+		if (t2a < -box_HALFdim[n1]) assertion_failed(__FILE__, __LINE__, "PBC failed ; a-");
 	}
 	else if (t2a > +box_HALFdim[n1])
 	{
 		t2a -= 2.0 * box_HALFdim[n1];
-		if (t2a > +box_HALFdim[n1])
-		{
-			cout << "PBC failed ; a+" << endl;
-			exit(EXIT_FAILURE);
-		}
+		if (t2a > +box_HALFdim[n1]) assertion_failed(__FILE__, __LINE__, "PBC failed ; a+");
 	}
 					
 					f64 t2b = crd[l2g_mm[ind2] * 3 + n1];
@@ -1694,20 +1651,12 @@ void eng1_mm_default_nbt_mim::UpdateTerms(void)
 	if (t2b < -box_HALFdim[n1])
 	{
 		t2b += 2.0 * box_HALFdim[n1];
-		if (t2b < -box_HALFdim[n1])
-		{
-			cout << "PBC failed ; b-" << endl;
-			exit(EXIT_FAILURE);
-		}
+		if (t2b < -box_HALFdim[n1]) assertion_failed(__FILE__, __LINE__, "PBC failed ; b-");
 	}
 	else if (t2b > +box_HALFdim[n1])
 	{
 		t2b -= 2.0 * box_HALFdim[n1];
-		if (t2b > +box_HALFdim[n1])
-		{
-			cout << "PBC failed ; b+" << endl;
-			exit(EXIT_FAILURE);
-		}
+		if (t2b > +box_HALFdim[n1]) assertion_failed(__FILE__, __LINE__, "PBC failed ; b+");
 	}
 					
 					t1a = t2a - t2b;
@@ -1801,7 +1750,7 @@ void eng1_mm_default_nbt_mim::UpdateTerms(void)
 	if (total_err && GetSetup()->GetModel()->verbosity >= 2)
 	{
 		ostringstream str;
-		str << "WARNING : there were " << total_err << " missing parameters in the nonbonded terms." << endl << ends;
+		str << _("WARNING : there were ") << total_err << _(" missing parameters in the nonbonded terms.") << endl << ends;
 		GetSetup()->GetModel()->PrintToLog(str.str().c_str());
 	}
 }
