@@ -23,6 +23,9 @@
 
 #include "v3d.h"
 
+#include "local_i18n.h"
+#include "notice.h"
+
 #include <iomanip>
 #include <fstream>
 #include <sstream>
@@ -62,14 +65,11 @@ eng1_mm_prmfit::eng1_mm_prmfit(setup * p1, i32u p2, prmfit_tables & tab) : engin
 
 	// create bt1-terms...
 	
-	if (ostr != NULL) (* ostr) << "creating bt1-terms: ";
+	if (ostr != NULL) (* ostr) << _("creating bt1-terms: ");
 	i32s bt1_err = 0;
 	
-if (!GetSetup()->GetModel()->IsIndexClean())	// obsolete???
-	{
-		cout << "BUG: is_index_clean == false at eng1_mm_prmfit" << endl;
-		exit(EXIT_FAILURE);
-	}
+	// 2008-12-17 ; an old comment suggested this test is obsolete? ; PROBABLY NOT!!! TH
+	if (!GetSetup()->GetModel()->IsIndexClean()) assertion_failed(__FILE__, __LINE__, "is_index_clean");
 	
 	for (i32s n1 = 0;n1 < GetSetup()->GetMMBondCount();n1++)
 	{
@@ -79,11 +79,7 @@ if (!GetSetup()->GetModel()->IsIndexClean())	// obsolete???
 			if (atmtab[local_ind1] == bndtab[n1]->atmr[0]) break;
 			else local_ind1++;
 		}
-		if (local_ind1 >= GetSetup()->GetMMAtomCount())
-		{
-			cout << "BUG: local_ind1 search failed!" << endl;
-			exit(EXIT_FAILURE);
-		}
+		if (local_ind1 >= GetSetup()->GetMMAtomCount()) assertion_failed(__FILE__, __LINE__, "local_ind1");
 		
 		i32s local_ind2 = 0;
 		while (local_ind2 < GetSetup()->GetMMAtomCount())
@@ -91,11 +87,7 @@ if (!GetSetup()->GetModel()->IsIndexClean())	// obsolete???
 			if (atmtab[local_ind2] == bndtab[n1]->atmr[1]) break;
 			else local_ind2++;
 		}
-		if (local_ind2 >= GetSetup()->GetMMAtomCount())
-		{
-			cout << "BUG: local_ind2 search failed!" << endl;
-			exit(EXIT_FAILURE);
-		}
+		if (local_ind2 >= GetSetup()->GetMMAtomCount()) assertion_failed(__FILE__, __LINE__, "local_ind2");
 		
 		mm_prmfit_bt1 newbt1;
 		newbt1.atmi[0] = local_ind1;		// this is a local index...
@@ -123,7 +115,7 @@ if (!GetSetup()->GetModel()->IsIndexClean())	// obsolete???
 		bt1_vector.push_back(newbt1);
 	}
 	
-	if (ostr != NULL) (* ostr) << bt1_vector.size() << " terms, " << bt1_err << " errors." << endl;
+	if (ostr != NULL) (* ostr) << bt1_vector.size() << _(" terms, ") << bt1_err << _(" errors.") << endl;
 	
 	bt1data = new mm_bt1_data[bt1_vector.size()];
 	
@@ -132,7 +124,7 @@ if (!GetSetup()->GetModel()->IsIndexClean())	// obsolete???
 	
 	// create bt2-terms...
 	
-	if (ostr != NULL) (* ostr) << "creating bt2-terms: ";
+	if (ostr != NULL) (* ostr) << _("creating bt2-terms: ");
 	i32s bt2_err = 0;
 	
 	for (i32s n1 = 0;n1 < GetSetup()->GetMMAtomCount();n1++)
@@ -189,7 +181,7 @@ if (!GetSetup()->GetModel()->IsIndexClean())	// obsolete???
 		}
 	}
 	
-	if (ostr != NULL) (* ostr) << bt2_vector.size() << " terms, " << bt2_err << " errors." << endl;
+	if (ostr != NULL) (* ostr) << bt2_vector.size() << _(" terms, ") << bt2_err << _(" errors.") << endl;
 	
 	bt2data = new mm_bt2_data[bt2_vector.size()];
 	
@@ -198,7 +190,7 @@ if (!GetSetup()->GetModel()->IsIndexClean())	// obsolete???
 	
 	// create bt3-terms...
 
-	if (ostr != NULL) (* ostr) << "creating bt3-terms: ";
+	if (ostr != NULL) (* ostr) << _("creating bt3-terms: ");
 	i32s bt3_err = 0;
 	
 	for (i32s n1 = 0;n1 < GetSetup()->GetMMAtomCount();n1++)
@@ -351,14 +343,14 @@ if (!GetSetup()->GetModel()->IsIndexClean())	// obsolete???
 		}
 	}
 	
-	if (ostr != NULL) (* ostr) << bt3_vector.size() << " terms, " << bt3_err << " errors." << endl;
+	if (ostr != NULL) (* ostr) << bt3_vector.size() << _(" terms, ") << bt3_err << _(" errors.") << endl;
 	
 /*##############################################*/
 /*##############################################*/
 
 	// create bt4-terms...
 	
-	if (ostr != NULL) (* ostr) << "creating bt4-terms: ";
+	if (ostr != NULL) (* ostr) << _("creating bt4-terms: ");
 	i32s bt4_err = 0;
 	
 	for (i32s n1 = 0;n1 < GetSetup()->GetMMAtomCount();n1++)
@@ -409,11 +401,7 @@ if (!GetSetup()->GetModel()->IsIndexClean())	// obsolete???
 				newbt4.index2++;
 			}
 			
-			if (newbt4.index2 == (i32s) bt2_vector.size())
-			{
-				cout << "BUG: bt2 missing for bt4!!!" << endl;
-				exit(EXIT_FAILURE);
-			}
+			if (newbt4.index2 == (i32s) bt2_vector.size()) assertion_failed(__FILE__, __LINE__, "index2 overflow");
 			
 			i32s iglob[4] =
 			{
@@ -432,15 +420,12 @@ if (!GetSetup()->GetModel()->IsIndexClean())	// obsolete???
 					else index++;
 				}
 				
-				if (index >= GetSetup()->GetMMAtomCount())
-				{
-					cout << "ERROR : iloc search failed!!!" << endl;
-					exit(EXIT_FAILURE);
-				}
+				if (index >= GetSetup()->GetMMAtomCount()) assertion_failed(__FILE__, __LINE__, "iloc search failed");
 				
 				newbt4.atmi[n9] = index;
 			}
-if (newbt4.atmi[1] != n1) { cout << "OOPS THIS IS NOT WORKING!!!" << endl; exit(EXIT_FAILURE); }
+			
+			if (newbt4.atmi[1] != n1) assertion_failed(__FILE__, __LINE__, "atmi[1] != n1");
 			
 	prmfit_op_query query; query.strict = false;
 	query.atmtp[0] = atmtab[newbt4.atmi[0]]->atmtp;
@@ -466,7 +451,7 @@ if (newbt4.atmi[1] != n1) { cout << "OOPS THIS IS NOT WORKING!!!" << endl; exit(
 		}
 	}
 	
-	if (ostr != NULL) (* ostr) << bt4_vector.size() << " terms, " << bt4_err << " errors." << endl;
+	if (ostr != NULL) (* ostr) << bt4_vector.size() << _(" terms, ") << bt4_err << _(" errors.") << endl;
 	
 /*##############################################*/
 /*##############################################*/
@@ -477,14 +462,14 @@ if (newbt4.atmi[1] != n1) { cout << "OOPS THIS IS NOT WORKING!!!" << endl; exit(
 	if (total_err && GetSetup()->GetModel()->verbosity >= 2)
 	{
 		ostringstream str;
-		str << "WARNING : there were " << total_err << " missing parameters in the bonded terms." << endl << ends;
+		str << _("WARNING : there were ") << total_err << _(" missing parameters in the bonded terms.") << endl << ends;
 		GetSetup()->GetModel()->PrintToLog(str.str().c_str());
 	}
 	
 /*##############################################*/
 /*##############################################*/
 
-	if (ostr != NULL) (* ostr) << "creating nbt1-terms: ";
+	if (ostr != NULL) (* ostr) << _("creating nbt1-terms: ");
 	i32s nbt1_err = 0;
 	
 	for (i32s ind1 = 0;ind1 < GetSetup()->GetMMAtomCount() - 1;ind1++)
@@ -552,7 +537,7 @@ if (newbt4.atmi[1] != n1) { cout << "OOPS THIS IS NOT WORKING!!!" << endl; exit(
 		}
 	}
 	
-	if (ostr != NULL) (* ostr) << nbt1_vector.size() << " terms, " << nbt1_err << " errors." << endl;
+	if (ostr != NULL) (* ostr) << nbt1_vector.size() << _(" terms, ") << nbt1_err << _(" errors.") << endl;
 	
 /*##############################################*/
 /*##############################################*/
@@ -563,7 +548,7 @@ if (newbt4.atmi[1] != n1) { cout << "OOPS THIS IS NOT WORKING!!!" << endl; exit(
 	if (total_err && GetSetup()->GetModel()->verbosity >= 2)
 	{
 		ostringstream str;
-		str << "WARNING : there were " << total_err << " missing parameters in the nonbonded terms." << endl << ends;
+		str << _("WARNING : there were ") << total_err << _(" missing parameters in the nonbonded terms.") << endl << ends;
 		GetSetup()->GetModel()->PrintToLog(str.str().c_str());
 	}
 }
@@ -591,11 +576,7 @@ i32s eng1_mm_prmfit::FindTorsion(atom * a1, atom * a2, atom * a3, atom * a4)
 			else index++;
 		}
 		
-		if (index >= GetSetup()->GetMMAtomCount())
-		{
-			cout << "ERROR : iloc search failed!!!" << endl;
-			exit(EXIT_FAILURE);
-		}
+		if (index >= GetSetup()->GetMMAtomCount()) assertion_failed(__FILE__, __LINE__, "iloc search failed");
 		
 		iloc[n1] = index;
 	}
