@@ -33,6 +33,8 @@ class eng1_qm;
 #include "model.h"
 #include "engine.h"
 
+#include "notice.h"
+
 /*################################################################################################*/
 
 // THE ID NUMBERS SHOULD NOT CHANGE!!! the numbering logic is the following:
@@ -123,8 +125,8 @@ class eng1_qm : virtual public engine
 	eng1_qm(setup *, i32u);
 	virtual ~eng1_qm(void);
 	
-	virtual bool SetTorsionConstraint(atom *, atom *, atom *, atom *, f64, f64, bool) { cout << "callEXIT : SetTorsionConstraint() is not yet implemented at eng1_qm!" << endl; exit(EXIT_FAILURE); }
-	virtual bool RemoveTorsionConstraint(atom *, atom *, atom *, atom *) { cout << "callEXIT : RemoveTorsionConstraint() is not yet implemented at eng1_qm!" << endl; exit(EXIT_FAILURE); }
+	virtual bool SetTorsionConstraint(atom *, atom *, atom *, atom *, f64, f64, bool) { assertion_failed(__FILE__, __LINE__, "not yet implemented!"); }
+	virtual bool RemoveTorsionConstraint(atom *, atom *, atom *, atom *) { assertion_failed(__FILE__, __LINE__, "not yet implemented!"); }
 	
 	virtual fGL GetVDWSurf(fGL *, fGL *);	// virtual
 };
