@@ -21,6 +21,8 @@
 #include "libghemicalconfig2.h"
 #include "eng1_qm_mpqc.h"	// config.h is here -> we get ENABLE-macros here...
 
+#include "local_i18n.h"
+
 #ifdef ENABLE_MPQC
 
 #include <sstream>
@@ -55,7 +57,7 @@ eng1_qm_mpqc::eng1_qm_mpqc(setup * p1, i32u p2, i32u mode) : eng1_qm(p1, p2), en
 	char filename[32];
 	GetInputFileName(filename, sizeof(filename));
 	
-	cout << "writing MPQC-input file " << filename << endl;
+	cout << _("writing MPQC-input file ") << filename << endl;
 	
 	ofstream file(filename, ios::out);
 	WriteInputFile(file, mode);
@@ -69,10 +71,10 @@ eng1_qm_mpqc::eng1_qm_mpqc(setup * p1, i32u p2, i32u mode) : eng1_qm(p1, p2), en
 	// however, it seems that we can skip this if we are not doing parallel processing...
 	
 	grp = MessageGrp::get_default_messagegrp();
-	cout << "using " << grp->class_name() << " as MessageGroup..." << endl;
+	cout << _("using ") << grp->class_name() << _(" as MessageGroup...") << endl;
 	
 	thread = ThreadGrp::get_default_threadgrp();
-	cout << "using " << thread->class_name() << " as ThreadGroup..." << endl;
+	cout << _("using ") << thread->class_name() << _(" as ThreadGroup...") << endl;
 	
 	parsedkv = new ParsedKeyVal(filename);
 #if(SC_MAJOR_VERSION == 1)
@@ -108,7 +110,7 @@ eng1_qm_mpqc::eng1_qm_mpqc(setup * p1, i32u p2, i32u mode) : eng1_qm(p1, p2), en
 #endif
 
 	MolecularFormula mf(mole->molecule());
-	cout << "molecular formula = " << mf.formula() << endl;
+	cout << _("molecular formula = ") << mf.formula() << endl;
 	
 	// it seems that we have to calculate energy here.
 	// it initializes something somewhere (problems in geometry changes).
@@ -130,11 +132,7 @@ void eng1_qm_mpqc::GetInputFileName(char * fn, i32u maxlen)
 	ostringstream str;
 	str << "/tmp/mpqc" << setfill('0') << setw(4) << ifile_name_counter++ << ".in" << ends;
 	
-	if (strlen(str.str().c_str()) + 1 >= maxlen)
-	{
-		cout << "maxlen exceeded!" << endl;
-		exit(EXIT_FAILURE);
-	}
+	if (strlen(str.str().c_str()) + 1 >= maxlen) assertion_failed(__FILE__, __LINE__, "maxlen exceeded");
 	
 	strcpy(fn, str.str().c_str());
 }
@@ -303,8 +301,7 @@ void eng1_qm_mpqc::Compute(i32u p1, bool)
 	}
 	else	// can't calculate higher derivatives just yet...
 	{
-		cout << "BUG: no d2 available at eng1_qm_mpqc::Compute()" << endl;
-		exit(EXIT_FAILURE);
+		assertion_failed(__FILE__, __LINE__, "not_implemented");
 	}
 }
 
@@ -387,7 +384,9 @@ fGL eng1_qm_mpqc::GetESP(fGL * pp, fGL * dd)
 		
 		const f64 t9a = 138.9354518;
 		f64 atnum = atmtab[n1]->el.GetAtomicNumber();
-		if (atnum < 0.5) { cout << "BUG: bad atnum!!!" << endl; exit(EXIT_FAILURE); }
+		
+		if (atnum < 0.5) assertion_failed(__FILE__, __LINE__, "bad atnum");
+		
 		value += t9a * atnum / t1c;
 	}
 	
