@@ -2,8 +2,19 @@
 
 // Copyright (C) 1998 Tommi Hassinen.
 
-// This program is free software; you can redistribute it and/or modify it
-// under the terms of the license (GNU GPL) which comes with this package.
+// This package is free software; you can redistribute it and/or modify
+// it under the terms of the GNU General Public License as published by
+// the Free Software Foundation; either version 2 of the License, or
+// (at your option) any later version.
+
+// This package is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+// GNU General Public License for more details.
+
+// You should have received a copy of the GNU General Public License
+// along with this package; if not, write to the Free Software
+// Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
 
 /*################################################################################################*/
 
@@ -172,6 +183,8 @@ class sf_res		// residue
 	atom * GetRefA(i32u atmi) { return (atmi < 3 ? atmr[atmi] : NULL); }
 	
 	i32u GetState(void) { return state; }
+	
+	char GetSymbol(void) { return symbol; }
 };
 
 /*################################################################################################*/
@@ -223,11 +236,16 @@ class sf_helix4info
 	i32u chn;
 	i32u res[2];
 	
-	vector<atom *> ua_donacc;
-	vector<atom *> cg_donacc;
+	vector<atom *> mc_H_don;
+	vector<atom *> mc_H_acc;
+	
+	vector<atom *> ca_H_don;
+	vector<atom *> ca_H_acc;
 	
 	friend class setup1_sf;
 	
+friend class project;		// this is for ghemical...
+	
 	public:
 	
 	sf_helix4info(i32u c, i32u rb, i32u re)
@@ -244,16 +262,6 @@ class sf_helix4info
 	i32u GetChn(void) { return chn; }
 	i32u GetResBgn(void) { return res[0]; }
 	i32u GetResEnd(void) { return res[1]; }
-	
-	void CopyDAVectUA(vector<atom *> & v)
-	{
-		v = ua_donacc;
-	}
-	
-	void CopyDAVectCG(vector<atom *> & v)
-	{
-		v = cg_donacc;
-	}
 };
 
 class sf_strandinfo
@@ -297,12 +305,15 @@ class sf_strandpair
 	
 	friend class setup1_sf;
 	
+friend class project;		// this is for ghemical...
+	
 	public:
 	
-	vector<atom *> ua_donacc;
+	vector<atom *> mc_S_don;
+	vector<atom *> mc_S_acc;
 	
-	vector<atom *> cg_straight;
-	vector<atom *> cg_crossed;
+	vector<atom *> ca_S_2x;
+	vector<atom *> cx_S_2x;
 	
 	public:
 	
@@ -355,7 +366,7 @@ class setup1_sf : virtual public setup
 	vector<sf_chn> chn_vector;
 	vector<sf_dsb> dsb_vector;
 	
-	bool united_atoms;
+	enum SFmode { modeUA = 0, modeP5 = 1, modeP3 = 2 } mode;
 	
 	vector<sf_helix4info> hi_vector;
 	vector<sf_strandinfo> si_vector;
@@ -375,7 +386,7 @@ class setup1_sf : virtual public setup
 	
 	public:
 	
-	setup1_sf(model *, bool, bool = true);
+	setup1_sf(model *, SFmode, bool = true);
 	~setup1_sf(void);
 	
 	void UpdateAtomFlags(void);		// virtual
@@ -392,7 +403,7 @@ class setup1_sf : virtual public setup
 	i32u GetEngineCount(void);		// virtual
 	i32u GetEngineIDNumber(i32u);		// virtual
 	const char * GetEngineName(i32u);	// virtual
-	const char * GetClassName(void);	// virtual
+	const char * GetClassName_lg(void);	// virtual
 	
 	engine * CreateEngineByIndex(i32u);	// virtual
 };
