@@ -21,6 +21,8 @@
 #include "libghemicalconfig2.h"
 #include "eng2_qm_mm.h"
 
+#include "local_i18n.h"
+
 /*################################################################################################*/
 
 // THE ID NUMBERS SHOULD NOT CHANGE!!! the numbering logic is the following:
@@ -96,8 +98,7 @@ setup2_qm_mm::~setup2_qm_mm(void)
 
 void setup2_qm_mm::UpdateAtomFlags(void)
 {
-cout << "not yet ready!" << endl;
-exit(EXIT_FAILURE);
+	assertion_failed(__FILE__, __LINE__, "not_implemented");
 }
 
 i32u setup2_qm_mm::static_GetEngineCount(void)
@@ -148,7 +149,7 @@ engine * setup2_qm_mm::CreateEngineByIndex(i32u eng_index)
 {
 	if (eng_index >= GetEngineCount())
 	{
-		cout << "setup2_qm_mm::CreateEngineByIndex() failed!" << endl;
+		cout << "WARNING : setup2_qm_mm::CreateEngineByIndex() failed!" << endl;
 		return NULL;
 	}
 	
@@ -169,7 +170,7 @@ engine * setup2_qm_mm::CreateEngineByIndex(i32u eng_index)
 		case ENG1_QM_MOPAC:
 		if (eng1_qm_mopac::GetLock() != NULL)
 		{
-			GetModel()->ErrorMessage("MOPAC lock failed!!!\nCan't run multiple MOPAC calculations.");
+			GetModel()->ErrorMessage(_("MOPAC lock failed!!!\nCan't run multiple MOPAC calculations."));
 			return NULL;
 		}
 		else return new eng2_qm_mm_mopac(this, 1, engtype2);
@@ -184,7 +185,7 @@ engine * setup2_qm_mm::CreateEngineByIndex(i32u eng_index)
 #endif	// ENABLE_MPQC
 		
 		default:
-		cout << "fatal error at setup2_qm_mm::CreateEngineByIndex()" << endl;
+		cout << "WARNING : setup2_qm_mm::CreateEngineByIndex() failed!" << endl;
 		return NULL;
 	}
 }
