@@ -2,8 +2,19 @@
 
 // Copyright (C) 1998 Tommi Hassinen.
 
-// This program is free software; you can redistribute it and/or modify it
-// under the terms of the license (GNU GPL) which comes with this package.
+// This package is free software; you can redistribute it and/or modify
+// it under the terms of the GNU General Public License as published by
+// the Free Software Foundation; either version 2 of the License, or
+// (at your option) any later version.
+
+// This package is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+// GNU General Public License for more details.
+
+// You should have received a copy of the GNU General Public License
+// along with this package; if not, write to the Free Software
+// Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
 
 /*################################################################################################*/
 
@@ -125,7 +136,7 @@ class setup
 	virtual i32u GetEngineCount(void) = 0;
 	virtual i32u GetEngineIDNumber(i32u) = 0;		// this is not much used yet. for saving eng info in files?!?!?!
 	virtual const char * GetEngineName(i32u) = 0;
-	virtual const char * GetClassName(void) = 0;
+	virtual const char * GetClassName_lg(void) = 0;		// also see model::AddAtom_lg() ; this is an another Win32 API conflict...
 	
 	void CreateCurrentEngine(void);				///< Create the current_eng object for plotting...
 	void DiscardCurrentEngine(void);
@@ -217,6 +228,8 @@ class engine
 	friend class moldyn;
 	friend class moldyn_langevin;
 	
+	friend class sasaeval;
+	
 	friend class random_search;
 	friend class systematic_search;
 	friend class monte_carlo_search;
@@ -243,7 +256,7 @@ class engine
 	
 	virtual void Compute(i32u, bool = false) = 0;	///< Will compute the energy, and the gradient if needed.
 	
-	virtual void DoSHAKE(void);		///< This is an optional method that contains some SHAKE-like corrections to atomic coordinates ; is called before calculating forces in MD.
+	virtual void DoSHAKE(bool);	///< This is an optional method that contains some SHAKE-like corrections to atomic coordinates ; is called before calculating forces in MD.
 	
 	// these are added to make it easier to set torsional constraints (like for plotting etc).
 	// ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
