@@ -2,8 +2,19 @@
 
 // Copyright (C) 1998 Tommi Hassinen.
 
-// This program is free software; you can redistribute it and/or modify it
-// under the terms of the license (GNU GPL) which comes with this package.
+// This package is free software; you can redistribute it and/or modify
+// it under the terms of the GNU General Public License as published by
+// the Free Software Foundation; either version 2 of the License, or
+// (at your option) any later version.
+
+// This package is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+// GNU General Public License for more details.
+
+// You should have received a copy of the GNU General Public License
+// along with this package; if not, write to the Free Software
+// Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
 
 /*################################################################################################*/
 
@@ -27,21 +38,18 @@ class geomopt_param
 {
 	protected:
 	
-	bool confirm;
-friend class w32_project;	// this is a temporary hack ; FIXME...
+	bool confirm;		// for GUI only...
 	
 	public:
 	
-	bool show_dialog;
-	
 	bool enable_nsteps;
 	i32s treshold_nsteps;
 	
 	bool enable_grad;
-	f64  treshold_grad;
+	f64 treshold_grad;
 	
 	bool enable_delta_e;
-	f64  treshold_delta_e;
+	f64 treshold_delta_e;
 	
 	public:
 	
@@ -49,14 +57,19 @@ friend class w32_project;	// this is a temporary hack ; FIXME...
 	{
 		confirm = false;
 		
-		show_dialog = true;
+	// set the defaults...
+	// ^^^^^^^^^^^^^^^^^^^
 		
+		enable_nsteps = true;
 		treshold_nsteps = 2500;
-		treshold_grad = 1.0e-3;
-		treshold_delta_e = 1.0e-7;
+	setup1_qm * suqm = dynamic_cast<setup1_qm *>(su);
+	if (suqm != NULL) treshold_nsteps = 500;		// override...
 		
-		setup1_qm * suqm = dynamic_cast<setup1_qm *>(su);
-		if (suqm != NULL) treshold_nsteps = 500;		// override...
+		enable_grad = true;
+		treshold_grad = 1.0e-3;
+		
+		enable_delta_e = false;
+		treshold_delta_e = 1.0e-7;
 	}
 	
 	~geomopt_param(void) { }
