@@ -26,6 +26,8 @@
 #include "atom.h"
 #include "bond.h"
 
+#include "notice.h"
+
 #include <iostream>
 using namespace std;
 
@@ -58,22 +60,17 @@ intcrd::intcrd(model & p1, i32s p2, i32s p3)
 	base[1].atmr = new atom(element(6), tmp2, mdl->GetCRDSetCount()); base[1].previous = & base[0];
 	base[2].atmr = new atom(element(6), tmp3, mdl->GetCRDSetCount()); base[2].previous = & base[1]; base[2].torv = 0.0;
 	
-	if (mdl->GetMoleculeCount() < 0)	// you must call mdl->GatherGroups before using this class!!!
-	{
-		cout << "BUG: invalid model at intcrd ctor." << endl;
-		exit(EXIT_FAILURE);
-	}
+	// you must call mdl->GatherGroups before using this class!!!
+	// ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
+	
+	if (mdl->GetMoleculeCount() < 0) assertion_failed(__FILE__, __LINE__, "mdl->GetMoleculeCount() < 0");
 	
 	// get the atom range for the molecule.
 	
 	iter_al range[2];
 	mdl->GetRange(0, molnum, range);
 	
-	if (range[0] == mdl->GetAtomsEnd())
-	{
-		cout << "BUG: invalid molecule at intcrd ctor." << endl;
-		exit(EXIT_FAILURE);
-	}
+	if (range[0] == mdl->GetAtomsEnd()) assertion_failed(__FILE__, __LINE__, "no_atoms");
 	
 	// find the best atom (the one with least bonds) to work as an "anchor".
 	
