@@ -2,8 +2,19 @@
 
 // Copyright (C) 1998 Tommi Hassinen.
 
-// This program is free software; you can redistribute it and/or modify it
-// under the terms of the license (GNU GPL) which comes with this package.
+// This package is free software; you can redistribute it and/or modify
+// it under the terms of the GNU General Public License as published by
+// the Free Software Foundation; either version 2 of the License, or
+// (at your option) any later version.
+
+// This package is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+// GNU General Public License for more details.
+
+// You should have received a copy of the GNU General Public License
+// along with this package; if not, write to the Free Software
+// Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
 
 /*################################################################################################*/
 
@@ -33,7 +44,7 @@
 #define DIR_SEPARATOR '/'	// directory separator
 #define EXT_SEPARATOR '.'	// extension separator
 
-#define NEWLINE "\n"	// a string that does the newline-operation.
+//#define NEWLINE "\n"	// a string that does the newline-operation.
 
 #define AMINO_BUILDER_FILE "builder/amino.txt"
 #define NUCLEIC_BUILDER_FILE "builder/nucleic.txt"
@@ -43,7 +54,7 @@
 #define DIR_SEPARATOR '\\'	// directory separator
 #define EXT_SEPARATOR '.'	// extension separator
 
-#define NEWLINE "\r\n"	// a string that does the newline-operation.
+//#define NEWLINE "\r\n"	// a string that does the newline-operation.
 
 #define AMINO_BUILDER_FILE "builder\\amino.txt"
 #define NUCLEIC_BUILDER_FILE "builder\\nucleic.txt"
