@@ -23,8 +23,10 @@
 
 #include "v3d.h"
 
-//#include <string.h>
-#include <cstring>	// required by gcc-4.3
+#include "local_i18n.h"
+#include "notice.h"
+
+#include <cstring>
 #include <iomanip>
 #include <iostream>
 #include <sstream>
@@ -133,17 +135,9 @@ mfinder::~mfinder(void)
 
 void mfinder::Identify(model * mdl)
 {
-	if (!mdl->IsGroupsClean())
-	{
-		cout << "BUG: is_groups_clean was false at mfinder::Identify()." << endl;
-		exit(EXIT_FAILURE);	//mdl->UpdateGroups();
-	}
+	if (!mdl->IsGroupsClean()) assertion_failed(__FILE__, __LINE__, "!mdl->IsGroupsClean()");
 	
-	if (mdl->ref_civ == NULL)
-	{
-		cout << "BUG: mdl->ref_civ == NULL at mfinder::Identify()." << endl;
-		exit(EXIT_FAILURE);
-	}
+	if (mdl->ref_civ == NULL) assertion_failed(__FILE__, __LINE__, "mdl->ref_civ == NULL");
 	
 cout << "mfinder::Identify() starts..." << endl;
 cout << "nmol = " << mdl->nmol << endl;
@@ -183,8 +177,8 @@ cout << "nmol = " << mdl->nmol << endl;
 		
 		if (head_atoms.size() > 0 && tail_atoms.size() > 0)
 		{
-			cout << "found " << head_atoms.size() << " possible heads and ";
-			cout << tail_atoms.size() << " possible tails." << endl;
+			cout << _("found ") << head_atoms.size() << _(" possible heads and ");
+			cout << tail_atoms.size() << _(" possible tails.") << endl;
 		}
 		
 		// now we have all possible head/tail atoms. next we have to check
@@ -201,7 +195,7 @@ cout << "nmol = " << mdl->nmol << endl;
 		
 		if (path_vector.size())
 		{
-			cout << path_vector.size() << " chains:" << endl;
+			cout << path_vector.size() << _(" chains:") << endl;
 		}
 		
 		for (i32s n2 = 0;n2 < (i32s) path_vector.size();n2++)
@@ -357,7 +351,7 @@ cout << "nmol = " << mdl->nmol << endl;
 				
 				if (tmp1[0] == NOT_DEFINED)
 				{
-					cout << "WARNING : residue " << rcount << " was of unknown type!!!" << endl;
+					cout << _("WARNING : residue ") << rcount << _(" was of unknown type!!!") << endl;
 					
 				//seq	molecule.push_back('?');				// handle the molecule...
 					
