@@ -2,8 +2,19 @@
 
 // Copyright (C) 1998 Tommi Hassinen.
 
-// This program is free software; you can redistribute it and/or modify it
-// under the terms of the license (GNU GPL) which comes with this package.
+// This package is free software; you can redistribute it and/or modify
+// it under the terms of the GNU General Public License as published by
+// the Free Software Foundation; either version 2 of the License, or
+// (at your option) any later version.
+
+// This package is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+// GNU General Public License for more details.
+
+// You should have received a copy of the GNU General Public License
+// along with this package; if not, write to the Free Software
+// Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
 
 /*################################################################################################*/
 
@@ -51,7 +62,7 @@ class moldyn_param;		// moldyn.h
 #include <algorithm>
 using namespace std;
 
-#define NOT_FOUND 0x7fffffff   // numeric_limits<i32s>::max()?!?!?!
+#define NOT_FOUND 0x7fffffff	// numeric_limits<i32s>::max()?!?!?!
 
 #define SF_NUM_TYPES 37
 
@@ -131,15 +142,7 @@ class model
 	public:
 	
 	static const char libversion[16];
-	
-#ifndef WIN32
-	
-	// in windows we need to get the installation path
-	// from system registry... see win32_hacks.cpp
-	
-	static const char libdata_path[256];
-	
-#endif	// WIN32
+	static char libdata_path[256];		// libghemical_init() will modify this...
 	
 	static const char sf_symbols[20 + 1];
 	static const i32s sf_types[SF_NUM_TYPES];
@@ -188,6 +191,9 @@ class model
 	
 	virtual void ThreadLock(void);
 	virtual void ThreadUnlock(void);
+	
+	virtual void NoThreadsIterate(void);
+	
 	virtual bool SetProgress(double, double *);
 	
 	virtual void Message(const char *);
@@ -246,8 +252,11 @@ class model
 	
 	// methods for adding new atoms and bonds:
 	// ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
+	// 2008-07-28 : AddAtom() was renamed into AddAtom_lg() in order to avoid problems caused by
+	// an another AddAtom()-something included in the Win32 API ; it is hard to understand why this is
+	// so bad problem in win32 but it is ; not even limited to MSVC -> perhaps about name mangling etc...
 	
-	virtual void AddAtom(atom &);		///< This will just push new atom to the atom list.
+	virtual void AddAtom_lg(atom &);	///< This will just push new atom to the atom list.
 	virtual void RemoveAtom(iter_al);	///< This will delete all bonds associated with this atom, and erase atom from the list...
 	
 	virtual void AddBond(bond &);		///< This will add neighbor infos for both atoms and add the new bond into the bond list.
@@ -370,15 +379,9 @@ This is private because only model::AddHydrogens() should use this... */
 /** This will perform geometry optimization. */
 	void DoGeomOpt(geomopt_param &, bool);
 	
-/** This is used to ask user the GO options; this default function will just silently accept the defaults. */
-	virtual void GeomOptGetParam(geomopt_param &);
-	
 /** This will perform molecular dynamics. */
 	void DoMolDyn(moldyn_param &, bool);
 	
-/** This is used to ask user the MD options; this default function will just silently accept the defaults. */
-	virtual void MolDynGetParam(moldyn_param &);
-	
 /** This will perform a random search using torsions as variables. */
 	void DoRandomSearch(i32s, i32s, bool);
 	
@@ -531,6 +534,10 @@ struct readpdb_data_ssbond
 
 /*################################################################################################*/
 
+void libghemical_init(const char *);
+
+/*################################################################################################*/
+
 #endif	// MODEL_H
 
 // eof
