@@ -2,8 +2,19 @@
 
 // Copyright (C) 1998 Tommi Hassinen.
 
-// This program is free software; you can redistribute it and/or modify it
-// under the terms of the license (GNU GPL) which comes with this package.
+// This package is free software; you can redistribute it and/or modify
+// it under the terms of the GNU General Public License as published by
+// the Free Software Foundation; either version 2 of the License, or
+// (at your option) any later version.
+
+// This package is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+// GNU General Public License for more details.
+
+// You should have received a copy of the GNU General Public License
+// along with this package; if not, write to the Free Software
+// Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
 
 /*################################################################################################*/
 
@@ -13,26 +24,24 @@
 class moldyn_param;
 
 class moldyn;
-class moldyn_langevin;
 
 /*################################################################################################*/
 
 #include "engine.h"
 #include "eng1_sf.h"
 
+#include <cstring>	// this is for std::strcpy ; 20071024
+
 /*################################################################################################*/
 
 class moldyn_param
 {
 	protected:
 	
-	bool confirm;
-friend class w32_project;	// this is a temporary hack ; FIXME...
+	bool confirm;		// for GUI only...
 	
 	public:
 	
-	bool show_dialog;
-	
 	i32s nsteps_h;		// heating
 	i32s nsteps_e;		// equilibration
 	i32s nsteps_s;		// simulation
@@ -51,8 +60,6 @@ friend class w32_project;	// this is a temporary hack ; FIXME...
 	bool constant_T;
 	bool constant_P;
 	
-	bool langevin;
-	
 	char filename[256];
 	
 	public:
@@ -61,8 +68,6 @@ friend class w32_project;	// this is a temporary hack ; FIXME...
 	{
 		confirm = false;
 		
-		show_dialog = true;
-		
 	// set the defaults...
 	// ^^^^^^^^^^^^^^^^^^^
 		
@@ -86,9 +91,7 @@ friend class w32_project;	// this is a temporary hack ; FIXME...
 		constant_T = true;
 		constant_P = false;
 		
-		langevin = false;
-		
-		strcpy(filename, "untitled.traj");
+		std::strcpy(filename, "untitled.traj");
 	}
 	
 	~moldyn_param(void) { }
@@ -168,43 +171,6 @@ class moldyn
 
 /*################################################################################################*/
 
-/**	A molecular dynamics class for Langevin dynamics.
-	
-	This is not any of the well-known LD integrators, just LD stuff added
-	on top of a "velocity Verlet" MD integrator.
-	
-	TODO : convert this is into a "BBK"-type integrator???
-*/
-
-class moldyn_langevin : public moldyn
-{
-	protected:
-	
-	eng1_sf * engsf;
-	
-	public:
-	
-	f64 * langevin_r_forces;
-	
-	f64 langevin_frict_fc;
-	f64 langevin_random_fc;
-	
-	f64 temperature_coupling;
-	f64 langevin_coupling;
-	
-	f64 * langevin_weight;
-	f64 * langevin_frict;
-	
-	public:
-	
-	moldyn_langevin(engine *, f64);
-	virtual ~moldyn_langevin(void);
-	
-	void TakeMDStep(bool);		// virtual...
-};
-
-/*################################################################################################*/
-
 #endif	// MOLDYN_H
 
 // eof
