@@ -21,8 +21,11 @@
 #include "libghemicalconfig2.h"
 #include "notice.h"
 
-#include <cstring>	// required by gcc-4.3
+#include "local_i18n.h"
+
+#include <cstring>
 #include <sstream>
+#include <cstdlib>
 using namespace std;
 
 /*################################################################################################*/
@@ -32,9 +35,9 @@ const char * get_lib_intro_notice_line(int line)
 	ostringstream str;
 	switch (line)
 	{
-		case 0:		str << "libghemical-" << LIBVERSION << " released on " << LIBRELEASEDATE << ends; break;
+		case 0:		str << _("libghemical-") << LIBVERSION << _(" released on ") << LIBRELEASEDATE << ends; break;
 		case 1:		str << " " << ends; break;
-		case 2:		str << "For more information please visit " << WEBSITE << ends; break;
+		case 2:		str << _("For more information please visit ") << WEBSITE << ends; break;
 		case 3:		str << " " << ends; break;
 		
 		default:	str << ends;
@@ -51,27 +54,27 @@ const char * get_copyright_notice_line(int line)
 	ostringstream str;
 	switch (line)
 	{
-		case 0:		str << "Copyright (C) 1998 Tommi Hassinen and others." << ends; break;
+		case 0:		str << _("Copyright (C) 1998 Tommi Hassinen and others.") << ends; break;
 		case 1:		str << " " << ends; break;
-		case 2:		str << "OpenBabel Copyright (C) 1998 OpenEye Scientific and others." << ends; break;
-		case 3:		str << "OpenBabel homepage is http://openbabel.sourceforge.net/" << ends; break;
+		case 2:		str << _("OpenBabel Copyright (C) 1998 OpenEye Scientific and others.") << ends; break;
+		case 3:		str << _("OpenBabel homepage is http://openbabel.sourceforge.net/") << ends; break;
 		case 4:		str << " " << ends; break;
-		case 5:		str << "MOPAC7 by James J.P. Stewart and others is in Public Domain." << ends; break;
-		case 6:		str << "The MOPAC7 based code (libmopac7) included in this program" << ends; break;
-		case 7:		str << "is also in Public Domain." << ends; break;
+		case 5:		str << _("MOPAC7 by James J.P. Stewart and others is in Public Domain.") << ends; break;
+		case 6:		str << _("The MOPAC7 based code (libmopac7) included in this program") << ends; break;
+		case 7:		str << _("is also in Public Domain.") << ends; break;
 		case 8:		str << " " << ends; break;
-		case 9:		str << "MPQC Copyright (C) 1997 Limit Point Systems, Inc. and others." << ends; break;
-		case 10:	str << "MPQC homepage is http://www.mpqc.org/" << ends; break;
+		case 9:		str << _("MPQC Copyright (C) 1997 Limit Point Systems, Inc. and others.") << ends; break;
+		case 10:	str << _("MPQC homepage is http://www.mpqc.org/") << ends; break;
 		case 11:	str << " " << ends; break;
-		case 12:	str << "This program is free software; you can redistribute it and/or" << ends; break;
-		case 13:	str << "modify it under the terms of the GNU General Public License" << ends; break;
-		case 14:	str << "as published by the Free Software Foundation; either version" << ends; break;
-		case 15:	str << "2 of the License, or any later version." << ends; break;
+		case 12:	str << _("This program is free software; you can redistribute it and/or") << ends; break;
+		case 13:	str << _("modify it under the terms of the GNU General Public License") << ends; break;
+		case 14:	str << _("as published by the Free Software Foundation; either version") << ends; break;
+		case 15:	str << _("2 of the License, or any later version.") << ends; break;
 		case 16:	str << " " << ends; break;
-		case 17:	str << "This program is distributed in the hope that it will be useful," << ends; break;
-		case 18:	str << "but WITHOUT ANY WARRANTY; without even the implied warranty of" << ends; break;
-		case 19:	str << "MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the" << ends; break;
-		case 20:	str << "GNU General Public License for more details." << ends; break;
+		case 17:	str << _("This program is distributed in the hope that it will be useful,") << ends; break;
+		case 18:	str << _("but WITHOUT ANY WARRANTY; without even the implied warranty of") << ends; break;
+		case 19:	str << _("MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the") << ends; break;
+		case 20:	str << _("GNU General Public License for more details.") << ends; break;
 		
 		default:	str << ends;
 	}
@@ -100,4 +103,15 @@ void print_copyright_notice(ostream & p1)
 
 /*################################################################################################*/
 
+void assertion_failed(const char * fn, int ln, const char * description)
+{
+	cout << _("FATAL ERROR : file ") << fn << _(" line ") << ln << _(" assertion failed : ");
+	cout << (description != NULL ? description : _("<no description>")) << endl;
+	cout << _("The program will now abort.") << endl;
+	
+	exit(EXIT_FAILURE);
+}
+
+/*################################################################################################*/
+
 // eof
