@@ -23,6 +23,9 @@
 
 #include "v3d.h"
 
+#include "local_i18n.h"
+#include "notice.h"
+
 /*################################################################################################*/
 
 pop_ana::pop_ana(setup1_qm * p1)
@@ -61,7 +64,10 @@ eng->Compute(0);//miksei vaikuta mitn???
 	// OBS!!! radii for the atoms/shells are taken from element::vdwr[] table!!!
 	// OBS!!! radii for the atoms/shells are taken from element::vdwr[] table!!!
 	
-	if (data_vector.size() != 0) { cout << "ooops!!! data_vector not empty." << endl; }
+	if (data_vector.size() != 0)
+	{
+		assertion_failed(__FILE__, __LINE__, "data_vector.size() != 0");
+	}
 	
 	int atom_counter = 0;
 	for (iter_al it1 = su->GetModel()->GetAtomsBegin();it1 != su->GetModel()->GetAtomsEnd();it1++)
@@ -83,8 +89,7 @@ eng->Compute(0);//miksei vaikuta mitn???
 			
 			if (rr == NOT_DEFINED)
 			{
-				cout << "bad rr!!!" << endl;
-				exit(EXIT_FAILURE);
+				assertion_failed(__FILE__, __LINE__, "rr == NOT_DEFINED");
 			}
 			
 			const fGL rsh1 = r1 * rr;
@@ -157,7 +162,7 @@ eng->Compute(0);//miksei vaikuta mitn???
 			}
 		}
 		
-		cout << "calculated " << point_counter << " data points for atom " << atom_counter++ << "." << endl;
+		cout << _("calculated ") << point_counter << _(" data points for atom ") << atom_counter++ << "." << endl;
 	}
 	
 	// then do the fitting...
@@ -178,9 +183,9 @@ eng->Compute(0);//miksei vaikuta mitn???
 	{
 		TakeCGStep(conjugate_gradient::Newton2An);
 		
-		cout << "step = " << n1 << " ";
-		cout << "value = " << optval << " ";
-		cout << "(optstp = " << optstp << ") ";
+		cout << _("step = ") << n1 << " ";
+		cout << _("value = ") << optval << " ";
+		cout << _("(optstp = ") << optstp << ") ";
 		cout << endl;
 	}
 	
