@@ -22,9 +22,11 @@
 #include "search.h"
 
 #include "utility.h"
-
 #include "eng1_qm_mopac.h"
 
+#include "local_i18n.h"
+#include "notice.h"
+
 #include <sstream>
 using namespace std;
 
@@ -57,7 +59,7 @@ random_search::random_search(model * p1, i32s p2, i32s p3, i32s p4, i32s p5, i32
 	
 	if (!ic->GetVariableCount())
 	{
-		mdl->ErrorMessage("ERROR: no rotatable bonds!!!");
+		mdl->ErrorMessage(_("ERROR: no rotatable bonds!!!"));
 		counter1 = cycles;	// skip the search...
 	}
 	
@@ -129,7 +131,7 @@ i32s random_search::TakeStep(void)
 			}
 			
 			ostringstream str1;
-			str1 << "step " << (counter1 + 1) << "/" << cycles << "   energy = " << eng->energy << " kJ/mol" << endl << ends;
+			str1 << _("step ") << (counter1 + 1) << "/" << cycles << _("   energy = ") << eng->energy << " kJ/mol" << endl << ends;
 			mdl->PrintToLog(str1.str().c_str());
 			
 			last_step = (counter1 + 1);
@@ -174,7 +176,7 @@ systematic_search::systematic_search(model * p1, i32s p2, i32s p3, i32s p4, i32s
 	}
 	else
 	{
-		mdl->ErrorMessage("ERROR: no rotatable bonds!!!");
+		mdl->ErrorMessage(_("ERROR: no rotatable bonds!!!"));
 		counter1 = NULL;	// skip the search...
 	}
 	
@@ -256,8 +258,8 @@ i32s systematic_search::TakeStep(void)
 			if (counter1 != NULL)
 			{
 				stringstream str1;
-				str1 << "step "; for (int v = 0;v < nvar;v++) { str1 << (char) ('A' + counter1[(nvar - 1) - v]); }
-				str1 << "   energy = " << eng->energy << " kJ/mol" << endl << ends;
+				str1 << _("step "); for (int v = 0;v < nvar;v++) { str1 << (char) ('A' + counter1[(nvar - 1) - v]); }
+				str1 << ("   energy = ") << eng->energy << " kJ/mol" << endl << ends;
 				mdl->PrintToLog(str1.str().c_str());
 			}
 			
@@ -299,7 +301,7 @@ monte_carlo_search::monte_carlo_search(model * p1, i32s p2, i32s p3, i32s p4, i3
 	
 	if (!ic->GetVariableCount())
 	{
-		mdl->ErrorMessage("ERROR: no rotatable bonds!!!");
+		mdl->ErrorMessage(_("ERROR: no rotatable bonds!!!"));
 		counter1 = n_simul_steps;	// skip the search...
 	}
 	
@@ -384,7 +386,7 @@ i32s monte_carlo_search::TakeStep(void)
 			f64 tmp2 = 1000.0 * tmp1 / (8.31451 * 300.0);
 			
 			if (!accept && ((fGL) rand() / (fGL) RAND_MAX < exp(-tmp2))) accept = true;
-	cout << counter1 << "   " << eng->energy << "   " << curr_energy << "   TESTVALUE = " << exp(-tmp2) << endl;
+	cout << counter1 << "   " << eng->energy << "   " << curr_energy << _("   TESTVALUE = ") << exp(-tmp2) << endl;
 			
 			if (accept)
 			{
@@ -396,7 +398,7 @@ i32s monte_carlo_search::TakeStep(void)
 				curr_energy = eng->energy;
 				
 				stringstream str1;
-				str1 << "step " << (counter1 + 1) << "/" << n_simul_steps << "   energy = " << eng->energy << " kJ/mol" << endl << ends;
+				str1 << _("step ") << (counter1 + 1) << "/" << n_simul_steps << _("   energy = ") << eng->energy << " kJ/mol" << endl << ends;
 				mdl->PrintToLog(str1.str().c_str());
 				
 				// set the weight???
@@ -457,13 +459,13 @@ transition_state_search::transition_state_search(model * p1, f64 p2, f64 p3)
 	
 	if (bad_setup)
 	{
-		mdl->ErrorMessage("Must use an all-QM/MOPAC setup!\nPlease see the User's Manual.");
+		mdl->ErrorMessage(_("Must use an all-QM/MOPAC setup!\nPlease see the User's Manual."));
 		return;
 	}
 	
 	if (mdl->GetAtomCount() % 2 != 0)
 	{
-		mdl->ErrorMessage("Atom count must be even!\nPlease see the User's Manual.");
+		mdl->ErrorMessage(_("Atom count must be even!\nPlease see the User's Manual."));
 		return;
 	}
 	
@@ -497,7 +499,7 @@ transition_state_search::transition_state_search(model * p1, f64 p2, f64 p3)
 		delete[] atab1; atab1 = NULL;
 		delete[] atab2; atab2 = NULL;
 		
-		mdl->ErrorMessage("No proper pair of reactants/products found!\nPlease see the User's Manual.");
+		mdl->ErrorMessage(_("No proper pair of reactants/products found!\nPlease see the User's Manual."));
 		return;
 	}
 	
@@ -552,7 +554,10 @@ transition_state_search::transition_state_search(model * p1, f64 p2, f64 p3)
 				if ((* it1).atmr[1] == atab2[n1]) ind1[1] = n1 + half;
 			}
 			
-			if (ind1[0] == NOT_DEFINED || ind1[1] == NOT_DEFINED) { cout << "tss ind1 search failed." << endl; exit(EXIT_FAILURE); }
+			if (ind1[0] == NOT_DEFINED || ind1[1] == NOT_DEFINED)
+			{
+				assertion_failed(__FILE__, __LINE__, "tss ind1 search failed.");
+			}
 			
 			bool has_equivalent = false;
 			for (iter_bl it2 = mdl->GetBondsBegin();it2 != mdl->GetBondsEnd();it2++)
@@ -569,7 +574,10 @@ transition_state_search::transition_state_search(model * p1, f64 p2, f64 p3)
 					if ((* it2).atmr[1] == atab2[n1]) ind2[1] = n1 + half;
 				}
 				
-				if (ind2[0] == NOT_DEFINED || ind2[1] == NOT_DEFINED) { cout << "tss ind2 search failed." << endl; exit(EXIT_FAILURE); }
+				if (ind2[0] == NOT_DEFINED || ind2[1] == NOT_DEFINED)
+				{
+					assertion_failed(__FILE__, __LINE__, "tss ind2 search failed.");
+				}
 				
 				if (ind1[0] == ind2[0] + (i32s) half && ind1[1] == ind2[1] + (i32s) half) has_equivalent = true;
 				if (ind1[0] + (i32s) half == ind2[0] && ind1[1] + (i32s) half == ind2[1]) has_equivalent = true;
@@ -590,8 +598,7 @@ transition_state_search::transition_state_search(model * p1, f64 p2, f64 p3)
 				else if (!bonded_to_r && bonded_to_p) bvect_p.push_back(& (* it1));
 				else
 				{
-					cout << "fatal bug in tss found!" << endl;
-					exit(EXIT_FAILURE);
+					assertion_failed(__FILE__, __LINE__, "a fatal error in tss!");
 				}
 			}
 		}
@@ -613,7 +620,10 @@ transition_state_search::transition_state_search(model * p1, f64 p2, f64 p3)
 				}
 			}
 			
-			if (atmi == NOT_DEFINED) { cout << "search r1 failed!" << endl; exit(EXIT_FAILURE); }
+			if (atmi == NOT_DEFINED)
+			{
+				assertion_failed(__FILE__, __LINE__, "search r1 failed!");
+			}
 			
 			bool unique = true;
 			for (i32u n3 = 0;n3 < patoms.size();n3++)
@@ -627,7 +637,10 @@ transition_state_search::transition_state_search(model * p1, f64 p2, f64 p3)
 		bond tmpb = bond(bvect_r[n1]->atmr[0], bvect_r[n1]->atmr[1], bondtype());
 		iter_bl itb = find(mdl->GetBondsBegin(), mdl->GetBondsEnd(), tmpb);
 		
-		if (itb == mdl->GetBondsEnd()) { cout << "search r2 failed!" << endl; exit(EXIT_FAILURE); }
+		if (itb == mdl->GetBondsEnd())
+		{
+			assertion_failed(__FILE__, __LINE__, "search r2 failed!");
+		}
 		
 		rbonds.push_back(& (* itb));	// we are on the reactant side -> the bond is ok!
 	}
@@ -651,7 +664,10 @@ transition_state_search::transition_state_search(model * p1, f64 p2, f64 p3)
 			}
 			
 			stored_atmi[n2] = atmi;
-			if (atmi == NOT_DEFINED) { cout << "search p1 failed!" << endl; exit(EXIT_FAILURE); }
+			if (atmi == NOT_DEFINED)
+			{
+				assertion_failed(__FILE__, __LINE__, "search p1 failed!");
+			}
 			
 			bool unique = true;
 			for (i32u n3 = 0;n3 < patoms.size();n3++)
@@ -665,7 +681,10 @@ transition_state_search::transition_state_search(model * p1, f64 p2, f64 p3)
 		bond tmpb = bond(bvect_p[n1]->atmr[0], bvect_p[n1]->atmr[1], bondtype());
 		iter_bl itb = find(mdl->GetBondsBegin(), mdl->GetBondsEnd(), tmpb);
 		
-		if (itb == mdl->GetBondsEnd()) { cout << "search p2 failed!" << endl; exit(EXIT_FAILURE); }
+		if (itb == mdl->GetBondsEnd())
+		{
+			assertion_failed(__FILE__, __LINE__, "search p2 failed!");
+		}
 		
 		// at the product side, we need to duplicate the bond in reactant side!!!
 		// ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
@@ -687,7 +706,10 @@ transition_state_search::transition_state_search(model * p1, f64 p2, f64 p3)
 			else it1++;
 		}
 		
-		if (it1 == mdl->GetAtomsEnd()) { cout << "tss : atom search failed!" << endl; exit(EXIT_FAILURE); }
+		if (it1 == mdl->GetAtomsEnd())
+		{
+			assertion_failed(__FILE__, __LINE__, "atom search failed!");
+		}
 		
 		mdl->RemoveAtom(it1);
 	}
@@ -701,7 +723,7 @@ transition_state_search::transition_state_search(model * p1, f64 p2, f64 p3)
 	for (i32s n1 = 0;n1 < 100;n1++)
 	{
 		si.TakeCGStep(conjugate_gradient::Newton2An);
-		cout << "step = " << n1 << " value = " << si.optval << endl;
+		cout << _("step = ") << n1 << _(" value = ") << si.optval << endl;
 	}
 	
 	si.Transform();
@@ -742,7 +764,7 @@ transition_state_search::transition_state_search(model * p1, f64 p2, f64 p3)
 		patoms.push_back(index);
 		
 		ostringstream txts;
-		txts << "no patoms found; using " << index << " as a default." << endl << ends;
+		txts << _("no patoms found; using ") << index << _(" as a default.") << endl << ends;
 		mdl->PrintToLog(txts.str().c_str());
 		
 		cout << txts.str().c_str();
@@ -764,8 +786,7 @@ transition_state_search::transition_state_search(model * p1, f64 p2, f64 p3)
 	
 	if (engQM == NULL)
 	{
-		cout << "tss : could not create engQM object!" << endl;
-		exit(EXIT_FAILURE);
+		assertion_failed(__FILE__, __LINE__, "engQM == NULL");
 	}
 	
 	bool problems = false;
@@ -776,8 +797,7 @@ transition_state_search::transition_state_search(model * p1, f64 p2, f64 p3)
 	
 	if (problems)
 	{
-		cout << "tss : l2g_qm is bad!" << endl;
-		exit(EXIT_FAILURE);
+		assertion_failed(__FILE__, __LINE__, "l2g_qm is bad!");
 	}
 	
 	for (i32s n1 = 0;n1 < 2;n1++)
@@ -860,7 +880,10 @@ transition_state_search::~transition_state_search(void)
 
 void transition_state_search::Run(i32s * prev_not_stored)
 {
-	if (init_failed) { cout << "tss init failed!" << endl; exit(EXIT_FAILURE); }
+	if (init_failed)
+	{
+		assertion_failed(__FILE__, __LINE__, "tss init failed!");
+	}
 	
 	for (i32s n1 = 0;n1 < 2;n1++)
 	{
@@ -922,7 +945,10 @@ void transition_state_search::Run(i32s * prev_not_stored)
 
 void transition_state_search::UpdateTargets(bool * update)
 {
-	if (init_failed) { cout << "tss init failed!" << endl; exit(EXIT_FAILURE); }
+	if (init_failed)
+	{
+		assertion_failed(__FILE__, __LINE__, "tss init failed!");
+	}
 	
 	if (!update[0] && !update[1]) return;
 	
@@ -959,7 +985,10 @@ void transition_state_search::UpdateTargets(bool * update)
 
 void transition_state_search::SetTarget(i32s index, i32s cset)
 {
-	if (init_failed) { cout << "tss init failed!" << endl; exit(EXIT_FAILURE); }
+	if (init_failed)
+	{
+		assertion_failed(__FILE__, __LINE__, "tss init failed!");
+	}
 	
 	iter_al it1; i32u counter = 0;
 	for (it1 = mdl->GetAtomsBegin();it1 != mdl->GetAtomsEnd();it1++)
