@@ -153,7 +153,7 @@ class sequencebuilder
 	
 	public:
 	
-	sequencebuilder(chn_info::chn_type, char *);
+	sequencebuilder(chn_info::chn_type, const char *);
 	~sequencebuilder(void);
 	
 	void Build(model *, sb_chain_descriptor *, bool = true);
