@@ -24,7 +24,9 @@
 #include "typerule.h"
 #include "utility.h"
 
-#include <cstring>	// required by gcc-4.3
+#include "local_i18n.h"
+
+#include <cstring>
 #include <iomanip>
 #include <fstream>
 #include <sstream>
@@ -55,7 +57,7 @@ prmfit_tables::prmfit_tables(const char * p1)
 	
 	file.open(fns.str().c_str(), ios::in);
 	
-	if (ostr != NULL) (* ostr) << "reading file \"" << fns.str() << "\": ";
+	if (ostr != NULL) (* ostr) << _("reading file \"") << fns.str() << "\": ";
 	
 	while (file.peek() != '#')		// #end
 	{
@@ -85,7 +87,7 @@ prmfit_tables::prmfit_tables(const char * p1)
 	
 	file.close();
 	
-	if (ostr != NULL) (* ostr) << "found " << at2_vector.size() << " atomtypes." << endl;
+	if (ostr != NULL) (* ostr) << _("found ") << at2_vector.size() << _(" atomtypes.") << endl;
 	
 /*##############################################*/
 /*##############################################*/
@@ -95,7 +97,7 @@ prmfit_tables::prmfit_tables(const char * p1)
 	
 	file.open(fns.str().c_str(), ios::in);
 	
-	if (ostr != NULL) (* ostr) << "reading file \"" << fns.str() << "\": ";
+	if (ostr != NULL) (* ostr) << _("reading file \"") << fns.str() << "\": ";
 	
 	while (file.peek() != '#')		// #end
 	{
@@ -114,7 +116,7 @@ prmfit_tables::prmfit_tables(const char * p1)
 	
 	file.close();
 	
-	if (ostr != NULL) (* ostr) << "found " << bs_vector.size() << " bs-terms." << endl;
+	if (ostr != NULL) (* ostr) << _("found ") << bs_vector.size() << _(" bs-terms.") << endl;
 	
 /*##############################################*/
 /*##############################################*/
@@ -124,7 +126,7 @@ prmfit_tables::prmfit_tables(const char * p1)
 	
 	file.open(fns.str().c_str(), ios::in);
 	
-	if (ostr != NULL) (* ostr) << "reading file \"" << fns.str() << "\": ";
+	if (ostr != NULL) (* ostr) << _("reading file \"") << fns.str() << "\": ";
 	
 	while (file.peek() != '#')		// #end
 	{
@@ -143,7 +145,7 @@ prmfit_tables::prmfit_tables(const char * p1)
 	
 	file.close();
 	
-	if (ostr != NULL) (* ostr) << "found " << ab_vector.size() << " ab-terms." << endl;
+	if (ostr != NULL) (* ostr) << _("found ") << ab_vector.size() << _(" ab-terms.") << endl;
 	
 /*##############################################*/
 /*##############################################*/
@@ -153,7 +155,7 @@ prmfit_tables::prmfit_tables(const char * p1)
 	
 	file.open(fns.str().c_str(), ios::in);
 	
-	if (ostr != NULL) (* ostr) << "reading file \"" << fns.str() << "\": ";
+	if (ostr != NULL) (* ostr) << _("reading file \"") << fns.str() << "\": ";
 	
 	while (file.peek() != '#')		// #end
 	{
@@ -172,7 +174,7 @@ prmfit_tables::prmfit_tables(const char * p1)
 	
 	file.close();
 	
-	if (ostr != NULL) (* ostr) << "found " << tr_vector.size() << " tr-terms." << endl;
+	if (ostr != NULL) (* ostr) << _("found ") << tr_vector.size() << _(" tr-terms.") << endl;
 
 /*##############################################*/
 /*##############################################*/
@@ -182,7 +184,7 @@ prmfit_tables::prmfit_tables(const char * p1)
 	
 	file.open(fns.str().c_str(), ios::in);
 	
-	if (ostr != NULL) (* ostr) << "reading file \"" << fns.str() << "\": ";
+	if (ostr != NULL) (* ostr) << _("reading file \"") << fns.str() << "\": ";
 	
 	while (file.peek() != '#')		// #end
 	{
@@ -201,7 +203,7 @@ prmfit_tables::prmfit_tables(const char * p1)
 	
 	file.close();
 	
-	if (ostr != NULL) (* ostr) << "found " << op_vector.size() << " op-terms." << endl;
+	if (ostr != NULL) (* ostr) << _("found ") << op_vector.size() << _(" op-terms.") << endl;
 	
 /*##############################################*/
 /*##############################################*/
@@ -228,7 +230,7 @@ void prmfit_tables::PrintAllTypeRules(ostream & p1)
 		p1 << " (" << (* at2_vector[n1].tr) << ") \"" << at2_vector[n1].description << "\"" << endl;
 	}
 	
-	p1 << at2_vector.size() << " entries." << endl;
+	p1 << at2_vector.size() << _(" entries.") << endl;
 }
 
 i32u prmfit_tables::UpdateTypes(setup * su)
@@ -238,7 +240,7 @@ i32u prmfit_tables::UpdateTypes(setup * su)
 	if (mdl->verbosity >= 3)
 	{
 		ostringstream str;
-		str << "Setting up atom types and formal charges..." << endl << ends;
+		str << _("Setting up atom types and formal charges...") << endl << ends;
 		
 		mdl->PrintToLog(str.str().c_str());
 	}
@@ -290,7 +292,7 @@ i32u prmfit_tables::UpdateTypes(setup * su)
 			if (mdl->verbosity >= 2)
 			{
 				ostringstream str;
-				str << "WARNING : could not determine atomtype (atom index = " << (* it1).index << ")." << endl << ends;
+				str << _("WARNING : could not determine atomtype (atom index = ") << (* it1).index << ")." << endl << ends;
 				
 				mdl->PrintToLog(str.str().c_str());
 			}
@@ -313,7 +315,7 @@ i32u prmfit_tables::UpdateCharges(setup * su)
 	if (mdl->verbosity >= 3)
 	{
 		ostringstream str;
-		str << "Setting up partial charges..." << endl << ends;
+		str << _("Setting up partial charges...") << endl << ends;
 		mdl->PrintToLog(str.str().c_str());
 	}
 	
@@ -398,7 +400,7 @@ void prmfit_tables::DoParamSearch(prmfit_bs_query * query, model * mdl)
 	if (mdl != NULL && mdl->verbosity >= 2)
 	{
 		ostringstream str;
-		str << "WARNING : unknown bs: ";
+		str << _("WARNING : unknown bs: ");
 		str << "0x" << hex << setw(4) << setfill('0') << query->atmtp[0] << dec << " ";
 		str << "0x" << hex << setw(4) << setfill('0') << query->atmtp[1] << dec << " ";
 		str << query->bndtp.GetValue() << " ";
@@ -476,7 +478,7 @@ void prmfit_tables::DoParamSearch(prmfit_ab_query * query, model * mdl)
 	if (mdl != NULL && mdl->verbosity >= 2)
 	{
 		ostringstream str;
-		str << "WARNING : unknown ab: ";
+		str << _("WARNING : unknown ab: ");
 		str << "0x" << hex << setw(4) << setfill('0') << query->atmtp[0] << dec << " ";
 		str << "0x" << hex << setw(4) << setfill('0') << query->atmtp[1] << dec << " ";
 		str << "0x" << hex << setw(4) << setfill('0') << query->atmtp[2] << dec << " ";
@@ -559,7 +561,7 @@ void prmfit_tables::DoParamSearch(prmfit_tr_query * query, model * mdl)
 	if (mdl != NULL && mdl->verbosity >= 2)
 	{
 		ostringstream str;
-		str << "WARNING : unknown tr: ";
+		str << _("WARNING : unknown tr: ");
 		str << "0x" << hex << setw(4) << setfill('0') << query->atmtp[0] << dec << " ";
 		str << "0x" << hex << setw(4) << setfill('0') << query->atmtp[1] << dec << " ";
 		str << "0x" << hex << setw(4) << setfill('0') << query->atmtp[2] << dec << " ";
@@ -656,7 +658,7 @@ void prmfit_tables::DoParamSearch(prmfit_op_query * query, model * mdl)
 	if (mdl != NULL && mdl->verbosity >= 2)
 	{
 		ostringstream str;
-		str << "WARNING : unknown op: ";
+		str << _("WARNING : unknown op: ");
 		str << "0x" << hex << setw(4) << setfill('0') << query->atmtp[0] << dec << " ";
 		str << "0x" << hex << setw(4) << setfill('0') << query->atmtp[1] << dec << " ";
 		str << "0x" << hex << setw(4) << setfill('0') << query->atmtp[2] << dec << " ";
