@@ -24,7 +24,9 @@
 #include "typerule.h"
 #include "utility.h"
 
-#include <cstring>	// required by gcc-4.3
+#include "local_i18n.h"
+
+#include <cstring>
 #include <fstream>
 #include <sstream>
 #include <iomanip>
@@ -52,7 +54,7 @@ tripos52_tables::tripos52_tables(void)
 	fn = "param_mm/tripos52/atomtypes.txt";
 	model::OpenLibDataFile(file, false, fn);
 	
-	if (ostr != NULL) (* ostr) << "reading file \"" << fn << "\": ";
+	if (ostr != NULL) (* ostr) << _("reading file \"") << fn << "\": ";
 	
 	while (file.peek() != '#')		// #end
 	{
@@ -77,7 +79,7 @@ tripos52_tables::tripos52_tables(void)
 	
 	file.close();
 	
-	if (ostr != NULL) (* ostr) << "found " << at_vector.size() << " atomtypes." << endl;
+	if (ostr != NULL) (* ostr) << _("found ") << at_vector.size() << _(" atomtypes.") << endl;
 	
 /*##############################################*/
 /*##############################################*/
@@ -85,7 +87,7 @@ tripos52_tables::tripos52_tables(void)
 	fn = "param_mm/tripos52/parameters1.txt";
 	model::OpenLibDataFile(file, false, fn);
 	
-	if (ostr != NULL) (* ostr) << "reading file \"" << fn << "\": ";
+	if (ostr != NULL) (* ostr) << _("reading file \"") << fn << "\": ";
 	
 	while (file.peek() != '#')		// #end
 	{
@@ -104,7 +106,7 @@ tripos52_tables::tripos52_tables(void)
 	
 	file.close();
 	
-	if (ostr != NULL) (* ostr) << "found " << bs_vector.size() << " bs-terms." << endl;
+	if (ostr != NULL) (* ostr) << _("found ") << bs_vector.size() << _(" bs-terms.") << endl;
 	
 /*##############################################*/
 /*##############################################*/
@@ -112,7 +114,7 @@ tripos52_tables::tripos52_tables(void)
 	fn = "param_mm/tripos52/parameters2.txt";
 	model::OpenLibDataFile(file, false, fn);
 	
-	if (ostr != NULL) (* ostr) << "reading file \"" << fn << "\": ";
+	if (ostr != NULL) (* ostr) << _("reading file \"") << fn << "\": ";
 	
 	while (file.peek() != '#')		// #end
 	{
@@ -131,7 +133,7 @@ tripos52_tables::tripos52_tables(void)
 	
 	file.close();
 	
-	if (ostr != NULL) (* ostr) << "found " << ab_vector.size() << " ab-terms." << endl;
+	if (ostr != NULL) (* ostr) << _("found ") << ab_vector.size() << _(" ab-terms.") << endl;
 	
 /*##############################################*/
 /*##############################################*/
@@ -139,7 +141,7 @@ tripos52_tables::tripos52_tables(void)
 	fn = "param_mm/tripos52/parameters3.txt";
 	model::OpenLibDataFile(file, false, fn);
 	
-	if (ostr != NULL) (* ostr) << "reading file \"" << fn << "\": ";
+	if (ostr != NULL) (* ostr) << _("reading file \"") << fn << "\": ";
 	
 	while (file.peek() != '#')		// #end
 	{
@@ -158,7 +160,7 @@ tripos52_tables::tripos52_tables(void)
 	
 	file.close();
 	
-	if (ostr != NULL) (* ostr) << "found " << tr_vector.size() << " tr-terms." << endl;
+	if (ostr != NULL) (* ostr) << _("found ") << tr_vector.size() << _(" tr-terms.") << endl;
 	
 /*##############################################*/
 /*##############################################*/
@@ -166,7 +168,7 @@ tripos52_tables::tripos52_tables(void)
 	fn = "param_mm/tripos52/parameters4.txt";
 	model::OpenLibDataFile(file, false, fn);
 	
-	if (ostr != NULL) (* ostr) << "reading file \"" << fn << "\": ";
+	if (ostr != NULL) (* ostr) << _("reading file \"") << fn << "\": ";
 	
 	while (file.peek() != '#')		// #end
 	{
@@ -184,7 +186,7 @@ tripos52_tables::tripos52_tables(void)
 	
 	file.close();
 	
-	if (ostr != NULL) (* ostr) << "found " << lj_vector.size() << " lj-datasets." << endl;
+	if (ostr != NULL) (* ostr) << _("found ") << lj_vector.size() << _(" lj-datasets.") << endl;
 	
 /*##############################################*/
 /*##############################################*/
@@ -192,7 +194,7 @@ tripos52_tables::tripos52_tables(void)
 	fn = "param_mm/tripos52/parameters5.txt";
 	model::OpenLibDataFile(file, false, fn);
 	
-	if (ostr != NULL) (* ostr) << "reading file \"" << fn << "\": ";
+	if (ostr != NULL) (* ostr) << _("reading file \"") << fn << "\": ";
 	
 	while (file.peek() != '#')		// #end
 	{
@@ -211,7 +213,7 @@ tripos52_tables::tripos52_tables(void)
 	
 	file.close();
 	
-	if (ostr != NULL) (* ostr) << "found " << ci_vector.size() << " ci-datasets." << endl;
+	if (ostr != NULL) (* ostr) << _("found ") << ci_vector.size() << _(" ci-datasets.") << endl;
 }
 
 tripos52_tables::~tripos52_tables(void)
@@ -237,7 +239,7 @@ void tripos52_tables::PrintAllTypeRules(ostream & p1)
 		p1 << " (" << (* at_vector[n1].tr) << ") \"" << at_vector[n1].description << "\"" << endl;
 	}
 	
-	p1 << at_vector.size() << " entries." << endl;
+	p1 << at_vector.size() << _(" entries.") << endl;
 }
 
 i32u tripos52_tables::UpdateTypes(setup * su)
@@ -247,7 +249,7 @@ i32u tripos52_tables::UpdateTypes(setup * su)
 	if (mdl->verbosity >= 3)
 	{
 		ostringstream str;
-		str << "Setting up atom types and formal charges..." << endl << ends;
+		str << _("Setting up atom types and formal charges...") << endl << ends;
 		
 		mdl->PrintToLog(str.str().c_str());
 	}
@@ -297,7 +299,7 @@ i32u tripos52_tables::UpdateTypes(setup * su)
 			if (mdl->verbosity >= 2)
 			{
 				ostringstream str;
-				str << "WARNING : could not determine atomtype (atom index = " << (* it1).index << ")." << endl << ends;
+				str << _("WARNING : could not determine atomtype (atom index = ") << (* it1).index << ")." << endl << ends;
 				
 				mdl->PrintToLog(str.str().c_str());
 			}
@@ -320,7 +322,7 @@ i32u tripos52_tables::UpdateCharges(setup * su)
 	if (mdl->verbosity >= 3)
 	{
 		ostringstream str;
-		str << "Setting up partial charges..." << endl << ends;
+		str << _("Setting up partial charges...") << endl << ends;
 		mdl->PrintToLog(str.str().c_str());
 	}
 	
@@ -365,7 +367,7 @@ f64 tripos52_tables::GetChargeInc(bond * ref, model * mdl)
 	if (mdl != NULL && mdl->verbosity >= 2)
 	{
 		ostringstream str;
-		str << "WARNING : there was no record for the following ci: ";
+		str << _("WARNING : there was no record for the following ci: ");
 		str << "0x" << hex << setw(4) << setfill('0') << atmtp[0] << dec << " ";
 		str << "0x" << hex << setw(4) << setfill('0') << atmtp[1] << dec << " ";
 		str << ref->bt.GetValue() << endl << ends;
@@ -423,7 +425,7 @@ bool tripos52_tables::Init(eng1_mm * eng, mm_tripos52_bt1 * ref, i32s bt)
 	if (mdl->verbosity >= 2)
 	{
 		ostringstream str;
-		str << "WARNING : unknown bst: ";
+		str << _("WARNING : unknown bst: ");
 		str << "0x" << hex << setw(4) << setfill('0') << atmtp[0] << dec << " ";
 		str << "0x" << hex << setw(4) << setfill('0') << atmtp[1] << dec << " ";
 		str << bt << endl << ends;
@@ -493,7 +495,7 @@ bool tripos52_tables::Init(eng1_mm * eng, mm_tripos52_bt2 * ref, i32s * bt)
 	if (mdl->verbosity >= 2)
 	{
 		ostringstream str;
-		str << "WARNING : unknown abn: " << hex;
+		str << _("WARNING : unknown abn: ") << hex;
 		str << "0x" << hex << setw(4) << setfill('0') << atmtp[0] << dec << " ";
 		str << "0x" << hex << setw(4) << setfill('0') << atmtp[1] << dec << " ";
 		str << "0x" << hex << setw(4) << setfill('0') << atmtp[2] << dec << " ";
@@ -568,7 +570,7 @@ bool tripos52_tables::Init(eng1_mm * eng, mm_tripos52_bt3 * ref, i32s * bt)
 	if (mdl->verbosity >= 2)
 	{
 		ostringstream str;
-		str << "WARNING : unknown tor: " << hex;
+		str << _("WARNING : unknown tor: ") << hex;
 		str << "0x" << hex << setw(4) << setfill('0') << atmtp[0] << dec << " ";
 		str << "0x" << hex << setw(4) << setfill('0') << atmtp[1] << dec << " ";
 		str << "0x" << hex << setw(4) << setfill('0') << atmtp[2] << dec << " ";
@@ -611,7 +613,7 @@ bool tripos52_tables::Init(eng1_mm * eng, mm_tripos52_nbt1 * ref, bool is14)
 			if (mdl->verbosity >= 2)
 			{
 				ostringstream str;
-				str << "WARNING : bad atomtype ; using hydrogen instead..." << endl << ends;
+				str << _("WARNING : bad atomtype ; using hydrogen instead...") << endl << ends;
 				
 				mdl->PrintToLog(str.str().c_str());
 			}
