@@ -2,8 +2,19 @@
 
 // Copyright (C) 1998 Tommi Hassinen.
 
-// This program is free software; you can redistribute it and/or modify it
-// under the terms of the license (GNU GPL) which comes with this package.
+// This package is free software; you can redistribute it and/or modify
+// it under the terms of the GNU General Public License as published by
+// the Free Software Foundation; either version 2 of the License, or
+// (at your option) any later version.
+
+// This package is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+// GNU General Public License for more details.
+
+// You should have received a copy of the GNU General Public License
+// along with this package; if not, write to the Free Software
+// Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
 
 /*################################################################################################*/
 
@@ -77,6 +88,7 @@ class tripos52_tables
 	private:
 	
 	static tripos52_tables * instance;
+	friend void libghemical_init(const char *);
 	
 	vector<tripos52_at> at_vector;
 	
