@@ -21,8 +21,10 @@
 #include "libghemicalconfig2.h"
 #include "typerule.h"
 
-//#include <string.h>
-#include <cstring>	// required by gcc-4.3
+#include "local_i18n.h"
+#include "notice.h"
+
+#include <cstring>
 #include <iomanip>
 #include <iostream>
 #include <sstream>
@@ -100,7 +102,7 @@ i32s typerule::ReadSubRule(istream * istr, ostream * ostr)
 				istr->get();
 				if (istr->peek() != 'l')
 				{
-					cout << "WARNING : typerule::ReadSubRule() failed (vl)." << endl;
+					cout << _("WARNING : typerule::ReadSubRule() failed (vl).") << endl;
 					return NOT_DEFINED;
 				}
 				
@@ -113,7 +115,7 @@ i32s typerule::ReadSubRule(istream * istr, ostream * ostr)
 				istr->get();
 				if (istr->peek() != 'c')
 				{
-					cout << "WARNING : typerule::ReadSubRule() failed (fc)." << endl;
+					cout << _("WARNING : typerule::ReadSubRule() failed (fc).") << endl;
 					return NOT_DEFINED;
 				}
 				
@@ -131,7 +133,7 @@ i32s typerule::ReadSubRule(istream * istr, ostream * ostr)
 					case 'D': newsr.type = tr_subrule::NumBondsDouble; break;
 					case 'T': newsr.type = tr_subrule::NumBondsTriple; break;
 					default:
-					cout << "WARNING : typerule::ReadSubRule() failed (b?)." << endl;
+					cout << _("WARNING : typerule::ReadSubRule() failed (b?).") << endl;
 					return NOT_DEFINED;
 				}
 				
@@ -148,7 +150,7 @@ i32s typerule::ReadSubRule(istream * istr, ostream * ostr)
 					case 'H': newsr.type = tr_subrule::NeighborsHydrogen; break;
 					case 'X': newsr.type = tr_subrule::NeighborsHighElNeg; break;
 					default:
-					cout << "WARNING : typerule::ReadSubRule() failed (n?)." << endl;
+					cout << _("WARNING : typerule::ReadSubRule() failed (n?).") << endl;
 					return NOT_DEFINED;
 				}
 				
@@ -193,8 +195,8 @@ i32s typerule::ReadSubRule(istream * istr, ostream * ostr)
 						bool problem = (el.GetAtomicNumber() == NOT_DEFINED && tmp2[0] != '*');
 						if (problem && ostr != NULL)
 						{
-							(* ostr) << "WARNING !!! Unknown element " << tmp2;
-							(* ostr) << " -> using wildcard instead..." << endl;
+							(* ostr) << _("WARNING : typerule::ReadSubRule() ring ; Unknown element ") << tmp2;
+							(* ostr) << _(" ; using '*' instead.") << endl;
 						}
 						
 						newring[n1] = (char) el.GetAtomicNumber();
@@ -212,8 +214,8 @@ i32s typerule::ReadSubRule(istream * istr, ostream * ostr)
 				bool problem1 = (newsr.bt.GetValue() == NOT_DEFINED && tmp1 != '?');
 				if (problem1 && ostr != NULL)
 				{
-					(* ostr) << "WARNING !!! Unknown bondtype " << tmp1;
-					(* ostr) << " -> using wildcard instead..." << endl;
+					(* ostr) << _("WARNING : typerule::ReadSubRule() bond ; Unknown bondtype ") << tmp1;
+					(* ostr) << _(" ; using '?' instead.") << endl;
 				}
 				
 				char tmp2[3] = { 0, 0, 0 }; tmp2[0] = (char) istr->get();
@@ -223,8 +225,8 @@ i32s typerule::ReadSubRule(istream * istr, ostream * ostr)
 				bool problem2 = (newsr.el.GetAtomicNumber() == NOT_DEFINED && tmp2[0] != '*');
 				if (problem2 && ostr != NULL)
 				{
-					(* ostr) << "WARNING !!! Unknown element " << tmp2;
-					(* ostr) << " -> using wildcard instead..." << endl;
+					(* ostr) << _("WARNING : typerule::ReadSubRule() bond ; Unknown element ") << tmp2;
+					(* ostr) << _(" ; using '*' instead.") << endl;
 				}
 				
 				newsr.sub = ReadSubRule(istr, ostr);
@@ -251,8 +253,7 @@ bool typerule::CheckRules(model * mdl, atom * atom, i32s flag, i32s rule)
 {
 	if ((flag + 1) >= BOND_NFLAGS)
 	{
-		cout << "callEXIT : flag array overflow at typerule::CheckRules()." << endl;
-		exit(EXIT_FAILURE);
+		assertion_failed(__FILE__, __LINE__, "flag array overflow.");
 	}
 	
 	i32s n1; iter_cl it1;
@@ -393,7 +394,7 @@ bool typerule::CheckRules(model * mdl, atom * atom, i32s flag, i32s rule)
 		else return true;
 		
 		default:
-		cout << "fatal error : unknown typerule!" << endl; exit(EXIT_FAILURE);
+		assertion_failed(__FILE__, __LINE__, "unknown typerule!");
 		return false;
 	}
 }
