@@ -22,9 +22,11 @@
 #include "utility.h"
 
 #include "v3d.h"
+#include "notice.h"
 
-//#include <string.h>
-#include <cstring>	// required by gcc-4.3
+#include "local_i18n.h"
+
+#include <cstring>
 #include <iomanip>
 #include <iostream>
 #include <sstream>
@@ -336,7 +338,7 @@ void DefineSecondaryStructure(model * mdl)
 		
 		delete[] energy;
 		
-		cout << "looking for intrachain strands for chain " << (n1 + 1) << endl;
+		cout << _("looking for intrachain strands for chain ") << (n1 + 1) << endl;
 		
 		for (i32s n2 = 1;n2 < ci_vector[n1].length - 4;n2++)
 		{
@@ -385,7 +387,7 @@ void DefineSecondaryStructure(model * mdl)
 		cout << endl;
 	}
 	
-	cout << "looking for interchain strands";
+	cout << _("looking for interchain strands");
 	
 	for (i32s n1 = 0;n1 < ((i32s) ci_vector.size()) - 1;n1++)
 	{
@@ -447,7 +449,7 @@ void DefineSecondaryStructure(model * mdl)
 	{
 		if (ci_vector[n1].type != chn_info::amino_acid) continue;
 		
-		cout << "// chain " << n1 << ":" << endl;
+		cout << _("found chain ") << n1 << " :" << endl;
 		
 		i32u length = strlen(ci_vector[n1].ss_state);
 		for (i32u n2 = 0;n2 < length;n2++)
@@ -463,7 +465,7 @@ void DefineSecondaryStructure(model * mdl)
 		cout << endl;
 	}
 	
-	cout << "DefineSecondaryStructure() is ready." << endl;
+	cout << _("DefineSecondaryStructure() is ready.") << endl;
 }
 
 // here can be some problems with the carboxyl terminus where
@@ -584,19 +586,19 @@ bool TorsionCheck(model * mdl, i32s chn, i32s * res, fGL ref)
 	
 	iter_al it_c1 = rr1[0];
 	while (it_c1 != rr1[1] && ((* it_c1).builder_res_id & 0xFF) != 0x02) it_c1++;
-	if (it_c1 == rr1[1]) { cout << "TC ; c_alpha #1 not found!" << endl; exit(EXIT_FAILURE); }
+	if (it_c1 == rr1[1]) assertion_failed(__FILE__, __LINE__, "c_alpha #1 not found.");
 	
 	iter_al it_c2 = rr2[0];
 	while (it_c2 != rr2[1] && ((* it_c2).builder_res_id & 0xFF) != 0x02) it_c2++;
-	if (it_c2 == rr2[1]) { cout << "TC ; c_alpha #2 not found!" << endl; exit(EXIT_FAILURE); }
+	if (it_c2 == rr2[1]) assertion_failed(__FILE__, __LINE__, "c_alpha #2 not found.");
 	
 	iter_al it_c3 = rr3[0];
 	while (it_c3 != rr3[1] && ((* it_c3).builder_res_id & 0xFF) != 0x02) it_c3++;
-	if (it_c3 == rr3[1]) { cout << "TC ; c_alpha #3 not found!" << endl; exit(EXIT_FAILURE); }
+	if (it_c3 == rr3[1]) assertion_failed(__FILE__, __LINE__, "c_alpha #3 not found.");
 	
 	iter_al it_c4 = rr4[0];
 	while (it_c4 != rr4[1] && ((* it_c4).builder_res_id & 0xFF) != 0x02) it_c4++;
-	if (it_c4 == rr4[1]) { cout << "TC ; c_alpha #4 not found!" << endl; exit(EXIT_FAILURE); }
+	if (it_c4 == rr4[1]) assertion_failed(__FILE__, __LINE__, "c_alpha #4 not found.");
 	
 	v3d<fGL> v1 = v3d<fGL>((* it_c2).GetCRD(0), (* it_c1).GetCRD(0));
 	v3d<fGL> v2 = v3d<fGL>((* it_c2).GetCRD(0), (* it_c3).GetCRD(0));
@@ -610,7 +612,7 @@ bool TorsionCheck(model * mdl, i32s chn, i32s * res, fGL ref)
 	if (fabs(dev) < HELIX_CHECK) return true;
 	else
 	{
-		cout << "HELIX CHECK FAILED : " << dev << endl;
+		cout << _("HELIX CHECK FAILED : ") << dev << endl;
 	//	int pause; cin >> pause;
 		
 		return false;
